pub struct CloudtrailClient<'a> { /* private fields */ }Expand description
Client for the AWS CloudTrail API
Implementations
Sourceimpl<'a> CloudtrailClient<'a>
impl<'a> CloudtrailClient<'a>
Sourcepub async fn describe_trails(
&self,
body: &DescribeTrailsRequest,
) -> Result<DescribeTrailsResponse>
pub async fn describe_trails( &self, body: &DescribeTrailsRequest, ) -> Result<DescribeTrailsResponse>
Retrieves settings for one or more trails associated with the current region.
Sourcepub async fn get_trail_status(
&self,
body: &GetTrailStatusRequest,
) -> Result<GetTrailStatusResponse>
pub async fn get_trail_status( &self, body: &GetTrailStatusRequest, ) -> Result<GetTrailStatusResponse>
Returns a JSON-formatted list of information about the specified trail.
Sourcepub async fn get_event_selectors(
&self,
body: &GetEventSelectorsRequest,
) -> Result<GetEventSelectorsResponse>
pub async fn get_event_selectors( &self, body: &GetEventSelectorsRequest, ) -> Result<GetEventSelectorsResponse>
Describes the settings for the event selectors configured for your trail.
Sourcepub async fn delete_trail(
&self,
body: &DeleteTrailRequest,
) -> Result<DeleteTrailResponse>
pub async fn delete_trail( &self, body: &DeleteTrailRequest, ) -> Result<DeleteTrailResponse>
Deletes a trail.
Sourcepub async fn update_trail(
&self,
body: &UpdateTrailRequest,
) -> Result<UpdateTrailResponse>
pub async fn update_trail( &self, body: &UpdateTrailRequest, ) -> Result<UpdateTrailResponse>
Updates trail settings that control what events you are logging.