pub struct CloudWatchClient<'a> { /* private fields */ }Expand description
Client for the Amazon CloudWatch API
Implementations
Sourceimpl<'a> CloudWatchClient<'a>
impl<'a> CloudWatchClient<'a>
Sourcepub async fn get_metric_statistics(
&self,
body: &GetMetricStatisticsInput,
) -> Result<GetMetricStatisticsResponse>
pub async fn get_metric_statistics( &self, body: &GetMetricStatisticsInput, ) -> Result<GetMetricStatisticsResponse>
Gets statistics for the specified metric.
Sourcepub async fn list_metrics(
&self,
body: &ListMetricsInput,
) -> Result<ListMetricsResponse>
pub async fn list_metrics( &self, body: &ListMetricsInput, ) -> Result<ListMetricsResponse>
List the specified metrics.
Sourcepub async fn describe_alarms(
&self,
body: &DescribeAlarmsInput,
) -> Result<DescribeAlarmsResponse>
pub async fn describe_alarms( &self, body: &DescribeAlarmsInput, ) -> Result<DescribeAlarmsResponse>
Retrieves the specified alarms.
Sourcepub async fn put_metric_alarm(&self, body: &PutMetricAlarmInput) -> Result<()>
pub async fn put_metric_alarm(&self, body: &PutMetricAlarmInput) -> Result<()>
Creates or updates an alarm and associates it with the specified metric.
Sourcepub async fn delete_alarms(&self, alarm_names: Vec<String>) -> Result<()>
pub async fn delete_alarms(&self, alarm_names: Vec<String>) -> Result<()>
Deletes the specified alarms.
Sourcepub async fn get_metric_data(
&self,
body: &GetMetricDataInput,
) -> Result<GetMetricDataResponse>
pub async fn get_metric_data( &self, body: &GetMetricDataInput, ) -> Result<GetMetricDataResponse>
Retrieves CloudWatch metric values for one or more metrics in a single batch request.
A single call can include up to 500 MetricDataQuery structures. Supports math
expressions across metrics. Use next_token in the returned response to page through
results when the requested time range yields more than max_datapoints data points.