DynamodbClient

Struct DynamodbClient 

pub struct DynamodbClient<'a> { /* private fields */ }
Client for the Amazon DynamoDB API

Implementations

Source

impl<'a> DynamodbClient<'a>

pub async fn list_tables( &self, body: &ListTablesInput, ) -> Result<ListTablesOutput>

Returns an array of table names associated with the current account and endpoint.

pub async fn describe_table( &self, body: &DescribeTableInput, ) -> Result<DescribeTableOutput>

Returns information about the table, including the current status of the table, when it was created, the primary key sch

pub async fn update_table( &self, body: &UpdateTableInput, ) -> Result<UpdateTableOutput>

Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table.

pub async fn delete_table( &self, body: &DeleteTableInput, ) -> Result<DeleteTableOutput>

The DeleteTable operation deletes a table and all of its items.