Ec2Client

Struct Ec2Client 

pub struct Ec2Client<'a> { /* private fields */ }
Client for the Amazon EC2 API

Implementations

Source

impl<'a> Ec2Client<'a>

pub async fn describe_instances( &self, body: &DescribeInstancesRequest, ) -> Result<DescribeInstancesResponse>

Describes the specified instances or all instances.

pub async fn describe_volumes( &self, body: &DescribeVolumesRequest, ) -> Result<DescribeVolumesResponse>

Describes the specified EBS volumes or all EBS volumes.

pub async fn describe_snapshots( &self, body: &DescribeSnapshotsRequest, ) -> Result<DescribeSnapshotsResponse>

Describes the specified EBS snapshots.

pub async fn describe_images( &self, body: &DescribeImagesRequest, ) -> Result<DescribeImagesResponse>

Describes the specified images (AMIs).

pub async fn describe_security_groups( &self, body: &DescribeSecurityGroupsRequest, ) -> Result<DescribeSecurityGroupsResponse>

Describes the specified security groups.

pub async fn describe_addresses( &self, body: &DescribeAddressesRequest, ) -> Result<DescribeAddressesResponse>

Describes the specified Elastic IP addresses.

pub async fn describe_nat_gateways( &self, body: &DescribeNatGatewaysRequest, ) -> Result<DescribeNatGatewaysResponse>

Describes the specified NAT gateways.

pub async fn describe_route_tables( &self, body: &DescribeRouteTablesRequest, ) -> Result<DescribeRouteTablesResponse>

Describes the specified route tables.

pub async fn describe_network_acls( &self, body: &DescribeNetworkAclsRequest, ) -> Result<DescribeNetworkAclsResponse>

Describes the specified network ACLs.

pub async fn describe_flow_logs( &self, body: &DescribeFlowLogsRequest, ) -> Result<DescribeFlowLogsResponse>

Describes the specified flow logs.

pub async fn describe_vpcs( &self, body: &DescribeVpcsRequest, ) -> Result<DescribeVpcsResponse>

Describes the specified VPCs.

pub async fn describe_vpc_endpoints( &self, body: &DescribeVpcEndpointsRequest, ) -> Result<DescribeVpcEndpointsResponse>

Describes the specified VPC endpoints.

pub async fn describe_vpc_peering_connections( &self, body: &DescribeVpcPeeringConnectionsRequest, ) -> Result<DescribeVpcPeeringConnectionsResponse>

Describes one or more VPC peering connections.

Optionally filter by connection IDs. Passing an empty slice returns all peering connections in the current account/region.

CIS 6.6: used to enumerate peering connections and cross-reference with describe_route_tables to verify that route tables don’t enable direct access between peered VPCs where it shouldn’t exist.

pub async fn list_vpc_peering_connections( &self, ) -> Result<Vec<VpcPeeringConnection>>

Return all VPC peering connections as a flat Vec.

pub async fn describe_launch_templates( &self, body: &DescribeLaunchTemplatesRequest, ) -> Result<DescribeLaunchTemplatesResponse>

Describes the specified launch templates.

pub async fn describe_launch_template_versions( &self, body: &DescribeLaunchTemplateVersionsRequest, ) -> Result<DescribeLaunchTemplateVersionsResponse>

Describes the specified launch template versions.

pub async fn describe_snapshot_attribute( &self, body: &DescribeSnapshotAttributeRequest, ) -> Result<DescribeSnapshotAttributeResponse>

Describes the specified attribute of the specified snapshot.

pub async fn get_ebs_encryption_by_default( &self, body: &GetEbsEncryptionByDefaultRequest, ) -> Result<GetEbsEncryptionByDefaultResponse>

Describes whether EBS encryption by default is enabled for the account.

pub async fn terminate_instances( &self, body: &TerminateInstancesRequest, ) -> Result<TerminateInstancesResponse>

Shuts down the specified instances.

pub async fn stop_instances( &self, body: &StopInstancesRequest, ) -> Result<StopInstancesResponse>

Stops the specified instances.

pub async fn start_instances( &self, body: &StartInstancesRequest, ) -> Result<StartInstancesResponse>

Starts the specified instances.

pub async fn modify_instance_attribute( &self, body: &ModifyInstanceAttributeRequest, ) -> Result<()>

Modifies the specified attribute of the specified instance.

pub async fn modify_instance_metadata_options( &self, body: &ModifyInstanceMetadataOptionsRequest, ) -> Result<ModifyInstanceMetadataOptionsResponse>

Modify the instance metadata parameters on a running or stopped instance.

pub async fn monitor_instances( &self, body: &MonitorInstancesRequest, ) -> Result<MonitorInstancesResponse>

Enables detailed monitoring for the specified instances.

pub async fn associate_iam_instance_profile( &self, body: &AssociateIamInstanceProfileRequest, ) -> Result<AssociateIamInstanceProfileResponse>

Associates an IAM instance profile with a running or stopped instance.

pub async fn detach_volume( &self, body: &DetachVolumeRequest, ) -> Result<VolumeAttachment>

Detaches an EBS volume from an instance.

pub async fn delete_volume(&self, body: &DeleteVolumeRequest) -> Result<()>

Deletes the specified EBS volume.

pub async fn modify_volume( &self, body: &ModifyVolumeRequest, ) -> Result<ModifyVolumeResponse>

Modifies the size, IOPS, throughput, or type of an EBS volume.

pub async fn create_snapshot( &self, body: &CreateSnapshotRequest, ) -> Result<Snapshot>

Creates a snapshot of an EBS volume.

pub async fn delete_snapshot(&self, body: &DeleteSnapshotRequest) -> Result<()>

Deletes the specified snapshot.

pub async fn modify_snapshot_attribute( &self, body: &ModifySnapshotAttributeRequest, ) -> Result<()>

Modifies the specified snapshot attribute.

pub async fn enable_snapshot_block_public_access( &self, body: &EnableSnapshotBlockPublicAccessRequest, ) -> Result<EnableSnapshotBlockPublicAccessResponse>

Enables the block public access for snapshots setting.

pub async fn deregister_image( &self, body: &DeregisterImageRequest, ) -> Result<DeregisterImageResponse>

Deregisters the specified AMI.

pub async fn modify_image_attribute( &self, body: &ModifyImageAttributeRequest, ) -> Result<()>

Modifies the specified attribute of the specified AMI.

pub async fn enable_image_block_public_access( &self, body: &EnableImageBlockPublicAccessRequest, ) -> Result<EnableImageBlockPublicAccessResponse>

Enables the block public access for AMIs setting.

pub async fn revoke_security_group_ingress( &self, body: &RevokeSecurityGroupIngressRequest, ) -> Result<RevokeSecurityGroupIngressResponse>

Removes the specified inbound rules from a security group.

pub async fn revoke_security_group_egress( &self, body: &RevokeSecurityGroupEgressRequest, ) -> Result<RevokeSecurityGroupEgressResponse>

Removes the specified outbound rules from a security group.

pub async fn authorize_security_group_ingress( &self, body: &AuthorizeSecurityGroupIngressRequest, ) -> Result<AuthorizeSecurityGroupIngressResponse>

Adds the specified inbound rules to a security group.

pub async fn delete_security_group( &self, body: &DeleteSecurityGroupRequest, ) -> Result<DeleteSecurityGroupResponse>

Deletes the specified security group.

pub async fn release_address(&self, body: &ReleaseAddressRequest) -> Result<()>

Releases the specified Elastic IP address.

pub async fn delete_nat_gateway( &self, body: &DeleteNatGatewayRequest, ) -> Result<DeleteNatGatewayResponse>

Deletes the specified NAT gateway.

pub async fn delete_vpc_endpoints( &self, body: &DeleteVpcEndpointsRequest, ) -> Result<DeleteVpcEndpointsResponse>

Deletes the specified VPC endpoints.

pub async fn create_flow_logs( &self, body: &CreateFlowLogsRequest, ) -> Result<CreateFlowLogsResponse>

Creates one or more flow logs.

pub async fn create_tags(&self, body: &CreateTagsRequest) -> Result<()>

Adds or overwrites only the specified tags for the specified resources.

pub async fn enable_ebs_encryption_by_default( &self, body: &EnableEbsEncryptionByDefaultRequest, ) -> Result<EnableEbsEncryptionByDefaultResponse>

Enables EBS encryption by default for the account.