pub struct EcsClient<'a> { /* private fields */ }Expand description
Client for the Amazon Elastic Container Service API
Implementations
Sourceimpl<'a> EcsClient<'a>
impl<'a> EcsClient<'a>
Sourcepub async fn list_clusters(
&self,
body: &ListClustersRequest,
) -> Result<ListClustersResponse>
pub async fn list_clusters( &self, body: &ListClustersRequest, ) -> Result<ListClustersResponse>
Returns a list of existing clusters.
Sourcepub async fn describe_clusters(
&self,
body: &DescribeClustersRequest,
) -> Result<DescribeClustersResponse>
pub async fn describe_clusters( &self, body: &DescribeClustersRequest, ) -> Result<DescribeClustersResponse>
Describes one or more of your clusters. For CLI examples, see describe-clusters.rst on GitHub.
Sourcepub async fn list_services(
&self,
body: &ListServicesRequest,
) -> Result<ListServicesResponse>
pub async fn list_services( &self, body: &ListServicesRequest, ) -> Result<ListServicesResponse>
Returns a list of services. You can filter the results by cluster, launch type, and scheduling strategy.
Sourcepub async fn describe_services(
&self,
body: &DescribeServicesRequest,
) -> Result<DescribeServicesResponse>
pub async fn describe_services( &self, body: &DescribeServicesRequest, ) -> Result<DescribeServicesResponse>
Describes the specified services running in your cluster.
Sourcepub async fn describe_task_definition(
&self,
body: &DescribeTaskDefinitionRequest,
) -> Result<DescribeTaskDefinitionResponse>
pub async fn describe_task_definition( &self, body: &DescribeTaskDefinitionRequest, ) -> Result<DescribeTaskDefinitionResponse>
Describes a task definition. You can specify a family and revision to find information about a specific task definition,
Sourcepub async fn update_service(
&self,
body: &UpdateServiceRequest,
) -> Result<UpdateServiceResponse>
pub async fn update_service( &self, body: &UpdateServiceRequest, ) -> Result<UpdateServiceResponse>
Modifies the parameters of a service. On March 21, 2024, a change was made to resolve the task definition revision befor
Sourcepub async fn deregister_task_definition(
&self,
body: &DeregisterTaskDefinitionRequest,
) -> Result<DeregisterTaskDefinitionResponse>
pub async fn deregister_task_definition( &self, body: &DeregisterTaskDefinitionRequest, ) -> Result<DeregisterTaskDefinitionResponse>
Deregisters the specified task definition by family and revision. Upon deregistration, the task definition is marked as