pub struct EmrClient<'a> { /* private fields */ }Expand description
Client for the Amazon EMR API
Implementations
Sourceimpl<'a> EmrClient<'a>
impl<'a> EmrClient<'a>
Sourcepub async fn list_clusters(
&self,
body: &ListClustersInput,
) -> Result<ListClustersOutput>
pub async fn list_clusters( &self, body: &ListClustersInput, ) -> Result<ListClustersOutput>
Provides the status of all clusters visible to this Amazon Web Services account.
Sourcepub async fn describe_cluster(
&self,
body: &DescribeClusterInput,
) -> Result<DescribeClusterOutput>
pub async fn describe_cluster( &self, body: &DescribeClusterInput, ) -> Result<DescribeClusterOutput>
Provides cluster-level details including status, hardware and software configuration, VPC settings, and so on.
Sourcepub async fn terminate_job_flows(
&self,
body: &TerminateJobFlowsInput,
) -> Result<()>
pub async fn terminate_job_flows( &self, body: &TerminateJobFlowsInput, ) -> Result<()>
TerminateJobFlows shuts a list of clusters (job flows) down. When a job flow is shut down, any step not yet completed is