pub struct KmsClient<'a> { /* private fields */ }Expand description
Client for the AWS Key Management Service API
Implementations
Sourceimpl<'a> KmsClient<'a>
impl<'a> KmsClient<'a>
Sourcepub async fn list_keys(
&self,
body: &ListKeysRequest,
) -> Result<ListKeysResponse>
pub async fn list_keys( &self, body: &ListKeysRequest, ) -> Result<ListKeysResponse>
Lists the key ARNs of all KMS keys in the current account and region.
Sourcepub async fn describe_key(
&self,
body: &DescribeKeyRequest,
) -> Result<DescribeKeyResponse>
pub async fn describe_key( &self, body: &DescribeKeyRequest, ) -> Result<DescribeKeyResponse>
Provides detailed information about a KMS key.
Sourcepub async fn get_key_rotation_status(
&self,
body: &GetKeyRotationStatusRequest,
) -> Result<GetKeyRotationStatusResponse>
pub async fn get_key_rotation_status( &self, body: &GetKeyRotationStatusRequest, ) -> Result<GetKeyRotationStatusResponse>
Gets a Boolean value that indicates whether automatic rotation of the key material is enabled for the specified KMS key.
Sourcepub async fn enable_key_rotation(
&self,
body: &EnableKeyRotationRequest,
) -> Result<()>
pub async fn enable_key_rotation( &self, body: &EnableKeyRotationRequest, ) -> Result<()>
Enables automatic rotation of the key material for the specified symmetric encryption KMS key.