pub struct RedshiftClient<'a> { /* private fields */ }Expand description
Client for the Amazon Redshift API
Implementations
Sourceimpl<'a> RedshiftClient<'a>
impl<'a> RedshiftClient<'a>
Sourcepub async fn describe_clusters(
&self,
body: &DescribeClustersRequest,
) -> Result<DescribeClustersResponse>
pub async fn describe_clusters( &self, body: &DescribeClustersRequest, ) -> Result<DescribeClustersResponse>
Returns properties of provisioned clusters including general cluster properties, cluster database properties, maintenanc
Sourcepub async fn pause_cluster(
&self,
body: &PauseClusterRequest,
) -> Result<PauseClusterResponse>
pub async fn pause_cluster( &self, body: &PauseClusterRequest, ) -> Result<PauseClusterResponse>
Pauses a cluster.
Sourcepub async fn resume_cluster(
&self,
body: &ResumeClusterRequest,
) -> Result<ResumeClusterResponse>
pub async fn resume_cluster( &self, body: &ResumeClusterRequest, ) -> Result<ResumeClusterResponse>
Resumes a paused cluster.
Sourcepub async fn resize_cluster(
&self,
body: &ResizeClusterRequest,
) -> Result<ResizeClusterResponse>
pub async fn resize_cluster( &self, body: &ResizeClusterRequest, ) -> Result<ResizeClusterResponse>
Changes the size of the cluster. You can change the cluster’s type, or change the number or type of nodes. The default b
Sourcepub async fn delete_cluster(
&self,
body: &DeleteClusterRequest,
) -> Result<DeleteClusterResponse>
pub async fn delete_cluster( &self, body: &DeleteClusterRequest, ) -> Result<DeleteClusterResponse>
Deletes a previously provisioned cluster without its final snapshot being created. A successful response from the web se