pub struct Route53Client<'a> { /* private fields */ }Expand description
Client for the Amazon Route 53 API
Implementations
Sourceimpl<'a> Route53Client<'a>
impl<'a> Route53Client<'a>
Sourcepub async fn list_hosted_zones(&self) -> Result<ListHostedZonesResponse>
pub async fn list_hosted_zones(&self) -> Result<ListHostedZonesResponse>
Retrieves a list of the public and private hosted zones associated with the current AWS account.
Sourcepub async fn list_resource_record_sets(
&self,
id: &str,
) -> Result<ListResourceRecordSetsResponse>
pub async fn list_resource_record_sets( &self, id: &str, ) -> Result<ListResourceRecordSetsResponse>
Lists the resource record sets in a specified hosted zone.
Sourcepub async fn list_health_checks(&self) -> Result<ListHealthChecksResponse>
pub async fn list_health_checks(&self) -> Result<ListHealthChecksResponse>
Retrieve a list of the health checks associated with the current AWS account.
Sourcepub async fn get_health_check_status(
&self,
health_check_id: &str,
) -> Result<GetHealthCheckStatusResponse>
pub async fn get_health_check_status( &self, health_check_id: &str, ) -> Result<GetHealthCheckStatusResponse>
Gets status of a health check based on the most recent checker observations.
Sourcepub async fn create_health_check(
&self,
body: &CreateHealthCheckRequest,
) -> Result<CreateHealthCheckResponse>
pub async fn create_health_check( &self, body: &CreateHealthCheckRequest, ) -> Result<CreateHealthCheckResponse>
Creates a new health check.
Sourcepub async fn delete_health_check(&self, health_check_id: &str) -> Result<()>
pub async fn delete_health_check(&self, health_check_id: &str) -> Result<()>
Deletes a health check.
Sourcepub async fn change_resource_record_sets(
&self,
id: &str,
body: &ChangeResourceRecordSetsRequest,
) -> Result<ChangeResourceRecordSetsResponse>
pub async fn change_resource_record_sets( &self, id: &str, body: &ChangeResourceRecordSetsRequest, ) -> Result<ChangeResourceRecordSetsResponse>
Creates, changes, or deletes a resource record set.
Route53 requires the Changes list to be wrapped with individual <Change> elements:
<Changes><Change>...</Change></Changes>. This method constructs that XML manually
because quick_xml’s default Vec serialization produces flat repeated tags.