pub struct SecretsmanagerClient<'a> { /* private fields */ }Expand description
Client for the AWS Secrets Manager API
Implementations
Sourceimpl<'a> SecretsmanagerClient<'a>
impl<'a> SecretsmanagerClient<'a>
Sourcepub async fn list_secrets(
&self,
body: &ListSecretsRequest,
) -> Result<ListSecretsResponse>
pub async fn list_secrets( &self, body: &ListSecretsRequest, ) -> Result<ListSecretsResponse>
Lists the secrets that are stored by Secrets Manager in the current account and Region.
Sourcepub async fn delete_secret(
&self,
body: &DeleteSecretRequest,
) -> Result<DeleteSecretResponse>
pub async fn delete_secret( &self, body: &DeleteSecretRequest, ) -> Result<DeleteSecretResponse>
Deletes a secret and all of its versions.
Sourcepub async fn rotate_secret(
&self,
body: &RotateSecretRequest,
) -> Result<RotateSecretResponse>
pub async fn rotate_secret( &self, body: &RotateSecretRequest, ) -> Result<RotateSecretResponse>
Configures and starts the asynchronous process of rotating the secret.