pub struct StsClient<'a> { /* private fields */ }Expand description
Client for the AWS Security Token Service API.
Implementations
Sourceimpl<'a> StsClient<'a>
impl<'a> StsClient<'a>
Sourcepub async fn get_caller_identity(&self) -> Result<GetCallerIdentityResponse>
pub async fn get_caller_identity(&self) -> Result<GetCallerIdentityResponse>
Returns details about the IAM user or role whose credentials are used to call the operation.
Sourcepub async fn assume_role(
&self,
body: &AssumeRoleRequest,
) -> Result<AssumeRoleResponse>
pub async fn assume_role( &self, body: &AssumeRoleRequest, ) -> Result<AssumeRoleResponse>
Returns a set of temporary security credentials for cross-account access.