pub struct AnalyzerSummary {
pub arn: String,
pub name: String,
pub type: String,
pub status: String,
pub created_at: String,
pub last_resource_analyzed_at: Option<String>,
pub last_resource_analyzed: Option<String>,
}Expand description
Contains information about the analyzer.
AWS API: accessanalyzer.v1.AnalyzerSummary
Reference: https://docs.aws.amazon.com/access-analyzer/latest/APIReference//AnalyzerSummary
Coverage
7 of 10 fields included. Omitted fields:
tags— not selected in manifeststatusReason— not selected in manifestconfiguration— not selected in manifest
Fields
arn: StringThe ARN of the analyzer.
name: StringThe name of the analyzer.
type: StringThe type represents the zone of trust or scope for the analyzer.
status: StringThe status of the analyzer. An Active analyzer successfully monitors supported resources and generates new findings. The analyzer is Disabled when a user action, such as removing trusted access for Identity and Access Management Access Analyzer from Organizations, causes the analyzer to stop generating new findings. The status is Creating when the analyzer creation is in progress and Failed when the analyzer creation has failed.
created_at: StringA timestamp for the time at which the analyzer was created.
last_resource_analyzed_at: Option<String>The time at which the most recently analyzed resource was analyzed.
last_resource_analyzed: Option<String>The resource that was most recently analyzed by the analyzer.