pub struct Distribution {
pub id: String,
pub arn: String,
pub status: String,
pub domain_name: String,
pub distribution_config: DistributionConfig,
}Expand description
A distribution tells CloudFront where you want content to be delivered from, and the details about how to track and manage content delivery.
AWS API: cloudfront.v1.Distribution
Reference: https://docs.aws.amazon.com/cloudfront/latest/APIReference/Distribution
Coverage
5 of 10 fields included. Omitted fields:
LastModifiedTime— not selected in manifestInProgressInvalidationBatches— not selected in manifestActiveTrustedSigners— not selected in manifestActiveTrustedKeyGroups— not selected in manifestAliasICPRecordals— not selected in manifest
Fields
id: StringThe distribution’s identifier. For example: E1U5RQF7T870K0.
arn: StringThe distribution’s Amazon Resource Name (ARN).
status: StringThe distribution’s status. When the status is Deployed, the distribution’s information is fully propagated to all CloudFront edge locations.
domain_name: StringThe distribution’s CloudFront domain name. For example: d111111abcdef8.cloudfront.net.
distribution_config: DistributionConfigThe distribution’s configuration.