pub struct GetTrailStatusRequest {
pub name: String,
}Expand description
The name of a trail about which you want the current status.
AWS API: cloudtrail.v1.GetTrailStatusRequest
Reference: https://docs.aws.amazon.com/awscloudtrail/latest/APIReference//GetTrailStatusRequest
Fields
name: StringSpecifies the name or the CloudTrail ARN of the trail for which you are requesting status. To get the status of a shadow trail (a replication of the trail in another Region), you must specify its ARN. The following is the format of a trail ARN: arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail If the trail is an organization trail and you are a member account in the organization in Organizations, you must provide the full ARN of that trail, and not just the name.