UpdateTableInput

Struct UpdateTableInput 

pub struct UpdateTableInput {
    pub table_name: String,
    pub billing_mode: Option<String>,
    pub provisioned_throughput: Option<ProvisionedThroughput>,
    pub deletion_protection_enabled: Option<bool>,
    pub table_class: Option<String>,
    pub stream_specification: Option<StreamSpecification>,
}
Represents the input of an UpdateTable operation.

AWS API: dynamodb.v1.UpdateTableInput Reference: https://docs.aws.amazon.com/amazondynamodb/latest/APIReference//UpdateTableInput

Coverage

6 of 14 fields included. Omitted fields:

  • AttributeDefinitions — not selected in manifest
  • GlobalSecondaryIndexUpdates — not selected in manifest
  • SSESpecification — not selected in manifest
  • ReplicaUpdates — not selected in manifest
  • MultiRegionConsistency — not selected in manifest
  • GlobalTableWitnessUpdates — not selected in manifest
  • OnDemandThroughput — not selected in manifest
  • WarmThroughput — not selected in manifest

Fields

table_name: String

The name of the table to be updated. You can also provide the Amazon Resource Name (ARN) of the table in this parameter.

billing_mode: Option<String>

Controls how you are charged for read and write throughput and how you manage capacity. When switching from pay-per-request to provisioned capacity, initial provisioned capacity values must be set. The initial provisioned capacity values are estimated based on the consumed read and write capacity of your table and global secondary indexes over the past 30 minutes. PAY_PER_REQUEST

  • We recommend using PAY_PER_REQUEST for most DynamoDB workloads. PAY_PER_REQUEST sets the billing mode to On-demand capacity mode. PROVISIONED
  • We recommend using PROVISIONED for steady workloads with predictable growth where capacity requirements can be reliably forecasted. PROVISIONED sets the billing mode to Provisioned capacity mode.
provisioned_throughput: Option<ProvisionedThroughput>

The new provisioned throughput settings for the specified table or index.

deletion_protection_enabled: Option<bool>

Indicates whether deletion protection is to be enabled (true) or disabled (false) on the table.

table_class: Option<String>

The table class of the table to be updated. Valid values are STANDARD and STANDARD_INFREQUENT_ACCESS.

stream_specification: Option<StreamSpecification>

Represents the DynamoDB Streams configuration for the table. You receive a ValidationException if you try to enable a stream on a table that already has a stream, or if you try to disable a stream on a table that doesn’t have a stream.