CreateFlowLogsRequest

Struct CreateFlowLogsRequest 

pub struct CreateFlowLogsRequest {
    pub resource_ids: Vec<String>,
    pub resource_type: String,
    pub traffic_type: String,
    pub log_group_name: Option<String>,
    pub deliver_logs_permission_arn: Option<String>,
}
AWS API: ec2.v1.CreateFlowLogsRequest Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//CreateFlowLogsRequest

Coverage

5 of 14 fields included. Omitted fields:

  • DryRun — not selected in manifest
  • ClientToken — not selected in manifest
  • DeliverCrossAccountRole — not selected in manifest
  • LogDestinationType — not selected in manifest
  • LogDestination — not selected in manifest
  • LogFormat — not selected in manifest
  • TagSpecifications — not selected in manifest
  • MaxAggregationInterval — not selected in manifest
  • DestinationOptions — not selected in manifest

Fields

resource_ids: Vec<String>

The IDs of the resources to monitor. For example, if the resource type is VPC, specify the IDs of the VPCs. Constraints: Maximum of 25 for transit gateway resource types. Maximum of 1000 for the other resource types.

resource_type: String

The type of resource to monitor.

traffic_type: String

The type of traffic to monitor (accepted traffic, rejected traffic, or all traffic). This parameter is not supported for transit gateway resource types. It is required for the other resource types.

log_group_name: Option<String>

The name of a new or existing CloudWatch Logs log group where Amazon EC2 publishes your flow logs. This parameter is valid only if the destination type is cloud-watch-logs.

deliver_logs_permission_arn: Option<String>

The ARN of the IAM role that allows Amazon EC2 to publish flow logs to the log destination. This parameter is required if the destination type is cloud-watch-logs, or if the destination type is kinesis-data-firehose and the delivery stream and the resources to monitor are in different accounts.