pub struct DescribeFlowLogsResponse {
pub flow_logs: Vec<FlowLog>,
pub next_token: Option<String>,
}Expand description
AWS API: ec2.v1.DescribeFlowLogsResult
Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//DescribeFlowLogsResult
Fields
flow_logs: Vec<FlowLog>Information about the flow logs.
next_token: Option<String>The token to request the next page of items. This value is null when there are no more items to return.