pub struct EnableEbsEncryptionByDefaultRequest {
pub dry_run: Option<bool>,
}Expand description
AWS API: ec2.v1.EnableEbsEncryptionByDefaultRequest
Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//EnableEbsEncryptionByDefaultRequest
Fields
dry_run: Option<bool>Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.