EnableImageBlockPublicAccessRequest

Struct EnableImageBlockPublicAccessRequest 

pub struct EnableImageBlockPublicAccessRequest {
    pub image_block_public_access_state: String,
}
AWS API: ec2.v1.EnableImageBlockPublicAccessRequest Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//EnableImageBlockPublicAccessRequest

Coverage

1 of 2 fields included. Omitted fields:

  • DryRun — not selected in manifest

Fields

image_block_public_access_state: String

Specify block-new-sharing to enable block public access for AMIs at the account level in the specified Region. This will block any attempt to publicly share your AMIs in the specified Region.