GetEbsEncryptionByDefaultRequest

Struct GetEbsEncryptionByDefaultRequest 

pub struct GetEbsEncryptionByDefaultRequest {
    pub dry_run: Option<bool>,
}
AWS API: ec2.v1.GetEbsEncryptionByDefaultRequest Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//GetEbsEncryptionByDefaultRequest

Fields

dry_run: Option<bool>

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.