InstanceMetadataOptionsResponse

Struct InstanceMetadataOptionsResponse 

pub struct InstanceMetadataOptionsResponse {
    pub http_tokens: Option<String>,
    pub http_endpoint: Option<String>,
}
The metadata options for the instance.

AWS API: ec2.v1.InstanceMetadataOptionsResponse Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//InstanceMetadataOptionsResponse

Coverage

2 of 6 fields included. Omitted fields:

  • State — not selected in manifest
  • HttpPutResponseHopLimit — not selected in manifest
  • HttpProtocolIpv6 — not selected in manifest
  • InstanceMetadataTags — not selected in manifest

Fields

http_tokens: Option<String>

Indicates whether IMDSv2 is required. optional

  • IMDSv2 is optional, which means that you can use either IMDSv2 or IMDSv1. required
  • IMDSv2 is required, which means that IMDSv1 is disabled, and you must use IMDSv2.
http_endpoint: Option<String>

Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled. If the value is disabled, you cannot access your instance metadata.