ModifyVolumeRequest

Struct ModifyVolumeRequest 

pub struct ModifyVolumeRequest {
    pub volume_id: String,
    pub volume_type: Option<String>,
    pub iops: Option<i32>,
    pub throughput: Option<i32>,
}
AWS API: ec2.v1.ModifyVolumeRequest Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//ModifyVolumeRequest

Coverage

4 of 7 fields included. Omitted fields:

  • DryRun — not selected in manifest
  • Size — not selected in manifest
  • MultiAttachEnabled — not selected in manifest

Fields

volume_id: String

The ID of the volume.

volume_type: Option<String>

The target EBS volume type of the volume. For more information, see Amazon EBS volume types in the Amazon EBS User Guide. Default: The existing type is retained.

iops: Option<i32>

The target IOPS rate of the volume. This parameter is valid only for gp3, io1, and io2 volumes. The following are the supported values for each volume type: gp3: 3,000 - 80,000 IOPS io1: 100 - 64,000 IOPS io2: 100 - 256,000 IOPS Instances built on the Nitro System can support up to 256,000 IOPS. Other instances can support up to 32,000 IOPS. Default: The existing value is retained if you keep the same volume type. If you change the volume type to io1, io2, or gp3, the default is 3,000.

throughput: Option<i32>

The target throughput of the volume, in MiB/s. This parameter is valid only for gp3 volumes. The maximum value is 2,000. Default: The existing value is retained if the source and target volume type is gp3. Otherwise, the default value is 125. Valid Range: Minimum value of 125. Maximum value of 2,000.