UpdateServiceRequest

Struct UpdateServiceRequest 

pub struct UpdateServiceRequest {
    pub cluster: Option<String>,
    pub service: String,
    pub desired_count: Option<i32>,
    pub task_definition: Option<String>,
    pub network_configuration: Option<NetworkConfiguration>,
    pub force_new_deployment: Option<bool>,
    pub health_check_grace_period_seconds: Option<i32>,
}
AWS API: ecs.v1.UpdateServiceRequest Reference: https://docs.aws.amazon.com/AmazonECS/latest/APIReference//UpdateServiceRequest

Coverage

7 of 22 fields included. Omitted fields:

  • capacityProviderStrategy — not selected in manifest
  • deploymentConfiguration — not selected in manifest
  • availabilityZoneRebalancing — not selected in manifest
  • placementConstraints — not selected in manifest
  • placementStrategy — not selected in manifest
  • platformVersion — not selected in manifest
  • deploymentController — not selected in manifest
  • enableExecuteCommand — not selected in manifest
  • enableECSManagedTags — not selected in manifest
  • loadBalancers — not selected in manifest
  • propagateTags — not selected in manifest
  • serviceRegistries — not selected in manifest
  • serviceConnectConfiguration — not selected in manifest
  • volumeConfigurations — not selected in manifest
  • vpcLatticeConfigurations — not selected in manifest

Fields

cluster: Option<String>

The short name or full Amazon Resource Name (ARN) of the cluster that your service runs on. If you do not specify a cluster, the default cluster is assumed. You can’t change the cluster name.

service: String

The name of the service to update.

desired_count: Option<i32>

The number of instantiations of the task to place and keep running in your service. This parameter doesn’t trigger a new service deployment.

task_definition: Option<String>

The family and revision (family:revision) or full ARN of the task definition to run in your service. If a revision is not specified, the latest ACTIVE revision is used. If you modify the task definition with UpdateService, Amazon ECS spawns a task with the new version of the task definition and then stops an old task after the new version is running. This parameter triggers a new service deployment.

network_configuration: Option<NetworkConfiguration>

An object representing the network configuration for the service. This parameter triggers a new service deployment.

force_new_deployment: Option<bool>

Determines whether to force a new deployment of the service. By default, deployments aren’t forced. You can use this option to start a new deployment with no service definition changes. For example, you can update a service’s tasks to use a newer Docker image with the same image/tag combination (my_image:latest) or to roll Fargate tasks onto a newer platform version.

health_check_grace_period_seconds: Option<i32>

The period of time, in seconds, that the Amazon ECS service scheduler ignores unhealthy Elastic Load Balancing, VPC Lattice, and container health checks after a task has first started. If you don’t specify a health check grace period value, the default value of 0 is used. If you don’t use any of the health checks, then healthCheckGracePeriodSeconds is unused. If your service’s tasks take a while to start and respond to health checks, you can specify a health check grace period of up to 2,147,483,647 seconds (about 69 years). During that time, the Amazon ECS service scheduler ignores health check status. This grace period can prevent the service scheduler from marking tasks as unhealthy and stopping them before they have time to come up. If your service has more running tasks than desired, unhealthy tasks in the grace period might be stopped to reach the desired count. This parameter doesn’t trigger a new service deployment.