pub struct DescribeFileSystemsResponse {
pub file_systems: Vec<FileSystemDescription>,
pub next_marker: Option<String>,
pub marker: Option<String>,
}Expand description
AWS API: efs.v1.DescribeFileSystemsResponse
Reference: https://docs.aws.amazon.com/efs/latest/ug/API_Operations.html/DescribeFileSystemsResponse
Fields
file_systems: Vec<FileSystemDescription>An array of file system descriptions.
next_marker: Option<String>Present if there are more file systems than returned in the response (String). You can use the NextMarker in the subsequent request to fetch the descriptions.
marker: Option<String>Present if provided by caller in the request (String).