NodegroupScalingConfig

Struct NodegroupScalingConfig 

pub struct NodegroupScalingConfig {
    pub min_size: Option<i32>,
    pub max_size: Option<i32>,
    pub desired_size: Option<i32>,
}
An object representing the scaling configuration details for the Auto Scaling group that is associated with your node group. When creating a node group, you must specify all or none of the properties. When updating a node group, you can specify any or none of the properties.

AWS API: eks.v1.NodegroupScalingConfig Reference: https://docs.aws.amazon.com/eks/latest/APIReference//NodegroupScalingConfig

Fields

min_size: Option<i32>

The minimum number of nodes that the managed node group can scale in to.

max_size: Option<i32>

The maximum number of nodes that the managed node group can scale out to. For information about the maximum number that you can specify, see Amazon EKS service quotas in the Amazon EKS User Guide.

desired_size: Option<i32>

The current number of nodes that the managed node group should maintain. If you use the Kubernetes Cluster Autoscaler, you shouldn’t change the desiredSize value directly, as this can cause the Cluster Autoscaler to suddenly scale up or scale down. Whenever this parameter changes, the number of worker nodes in the node group is updated to the specified size. If this parameter is given a value that is smaller than the current number of running worker nodes, the necessary number of worker nodes are terminated to match the given value. When using CloudFormation, no action occurs if you remove this parameter from your CFN template. This parameter can be different from minSize in some cases, such as when starting with extra hosts for testing. This parameter can also be different when you want to start with an estimated number of needed hosts, but let the Cluster Autoscaler reduce the number if there are too many. When the Cluster Autoscaler is used, the desiredSize parameter is altered by the Cluster Autoscaler (but can be out- of-date for short periods of time). the Cluster Autoscaler doesn’t scale a managed node group lower than minSize or higher than maxSize.