Module lambda

Module lambda 

Types for the AWS Lambda API (v1).

Auto-generated from the AWS Botocore Model. Do not edit manually — modify the manifest and re-run codegen.

Structs

EnvironmentResponse
The results of an operation to update or read environment variables. If the operation succeeds, the response contains the environment variables. If it fails, the response contains details about the error.
FunctionConfiguration
Details about a function’s configuration.
GetFunctionConfigurationRequest
AWS API: lambda.v1.GetFunctionConfigurationRequest
ListFunctionsRequest
AWS API: lambda.v1.ListFunctionsRequest
ListFunctionsResponse
A list of Lambda functions.
UpdateFunctionConfigurationRequest
AWS API: lambda.v1.UpdateFunctionConfigurationRequest
VpcConfigResponse
The VPC security groups and subnets that are attached to a Lambda function.