pub struct EnvironmentResponse {
pub variables: HashMap<String, String>,
}Expand description
The results of an operation to update or read environment variables. If the operation succeeds, the response contains the environment variables. If it fails, the response contains details about the error.
AWS API: lambda.v1.EnvironmentResponse
Coverage
1 of 2 fields included. Omitted fields:
Error— not selected in manifest
Fields
variables: HashMap<String, String>Environment variable key-value pairs. Omitted from CloudTrail logs.