FunctionConfiguration

Struct FunctionConfiguration 

pub struct FunctionConfiguration {
    pub function_name: String,
    pub function_arn: String,
    pub runtime: Option<String>,
    pub handler: Option<String>,
    pub code_size: Option<i64>,
    pub description: Option<String>,
    pub timeout: Option<i32>,
    pub memory_size: Option<i32>,
    pub last_modified: Option<String>,
    pub environment: Option<Option<EnvironmentResponse>>,
    pub vpc_config: Option<Option<VpcConfigResponse>>,
    pub architectures: Vec<String>,
}
Details about a function’s configuration.

AWS API: lambda.v1.FunctionConfiguration

Coverage

12 of 40 fields included. Omitted fields:

  • Role — not selected in manifest
  • CodeSha256 — not selected in manifest
  • Version — not selected in manifest
  • DeadLetterConfig — not selected in manifest
  • KMSKeyArn — not selected in manifest
  • TracingConfig — not selected in manifest
  • MasterArn — not selected in manifest
  • RevisionId — not selected in manifest
  • Layers — not selected in manifest
  • State — not selected in manifest
  • StateReason — not selected in manifest
  • StateReasonCode — not selected in manifest
  • LastUpdateStatus — not selected in manifest
  • LastUpdateStatusReason — not selected in manifest
  • LastUpdateStatusReasonCode — not selected in manifest
  • FileSystemConfigs — not selected in manifest
  • PackageType — not selected in manifest
  • ImageConfigResponse — not selected in manifest
  • SigningProfileVersionArn — not selected in manifest
  • SigningJobArn — not selected in manifest
  • EphemeralStorage — not selected in manifest
  • SnapStart — not selected in manifest
  • RuntimeVersionConfig — not selected in manifest
  • LoggingConfig — not selected in manifest
  • CapacityProviderConfig — not selected in manifest
  • ConfigSha256 — not selected in manifest
  • DurableConfig — not selected in manifest
  • TenancyConfig — not selected in manifest

Fields

function_name: String

The name of the function.

function_arn: String

The function’s Amazon Resource Name (ARN).

runtime: Option<String>

The identifier of the function’s runtime. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you’re deploying a function using a container image. The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation. For a list of all currently supported runtimes, see Supported runtimes.

handler: Option<String>

The function that Lambda calls to begin running your function.

code_size: Option<i64>

The size of the function’s deployment package, in bytes.

description: Option<String>

The function’s description.

timeout: Option<i32>

The amount of time in seconds that Lambda allows a function to run before stopping it.

memory_size: Option<i32>

The amount of memory available to the function at runtime.

last_modified: Option<String>

The date and time that the function was last updated, in ISO-8601 format (YYYY-MM- DDThh:mm:ss.sTZD).

environment: Option<Option<EnvironmentResponse>>

The function’s environment variables. Omitted from CloudTrail logs.

vpc_config: Option<Option<VpcConfigResponse>>

The function’s networking configuration.

architectures: Vec<String>

The instruction set architecture that the function supports. Architecture is a string array with one of the valid values. The default architecture value is x86_64.