DBInstance

Struct DBInstance 

pub struct DBInstance {
Show 24 fields pub db_instance_identifier: Option<String>, pub db_instance_class: Option<String>, pub engine: Option<String>, pub db_instance_status: Option<String>, pub master_username: Option<String>, pub db_name: Option<String>, pub endpoint: Option<Endpoint>, pub allocated_storage: Option<i32>, pub instance_create_time: Option<String>, pub preferred_backup_window: Option<String>, pub backup_retention_period: Option<i32>, pub availability_zone: Option<String>, pub preferred_maintenance_window: Option<String>, pub multi_az: Option<bool>, pub engine_version: Option<String>, pub auto_minor_version_upgrade: Option<bool>, pub publicly_accessible: Option<bool>, pub storage_type: Option<String>, pub storage_encrypted: Option<bool>, pub kms_key_id: Option<String>, pub dbi_resource_id: Option<String>, pub db_instance_arn: Option<String>, pub iops: Option<i32>, pub storage_throughput: Option<i32>,
}
Contains the details of an Amazon RDS DB instance. This data type is used as a response element in the operations CreateDBInstance, CreateDBInstanceReadReplica, DeleteDBInstance, DescribeDBInstances, ModifyDBInstance, PromoteReadReplica, RebootDBInstance, RestoreDBInstanceFromDBSnapshot, RestoreDBInstanceFromS3, RestoreDBInstanceToPointInTime, StartDBInstance, and StopDBInstance.

AWS API: rds.v1.DBInstance Reference: https://docs.aws.amazon.com/AmazonRDS/latest/APIReference//DBInstance

Coverage

24 of 90 fields included. Omitted fields:

  • DBSecurityGroups — not selected in manifest
  • VpcSecurityGroups — not selected in manifest
  • DBParameterGroups — not selected in manifest
  • DBSubnetGroup — not selected in manifest
  • UpgradeRolloutOrder — not selected in manifest
  • PendingModifiedValues — not selected in manifest
  • LatestRestorableTime — not selected in manifest
  • ReadReplicaSourceDBInstanceIdentifier — not selected in manifest
  • ReadReplicaDBInstanceIdentifiers — not selected in manifest
  • ReadReplicaDBClusterIdentifiers — not selected in manifest
  • ReplicaMode — not selected in manifest
  • LicenseModel — not selected in manifest
  • OptionGroupMemberships — not selected in manifest
  • CharacterSetName — not selected in manifest
  • NcharCharacterSetName — not selected in manifest
  • SecondaryAvailabilityZone — not selected in manifest
  • StatusInfos — not selected in manifest
  • TdeCredentialArn — not selected in manifest
  • DbInstancePort — not selected in manifest
  • DBClusterIdentifier — not selected in manifest
  • CACertificateIdentifier — not selected in manifest
  • DomainMemberships — not selected in manifest
  • CopyTagsToSnapshot — not selected in manifest
  • MonitoringInterval — not selected in manifest
  • EnhancedMonitoringResourceArn — not selected in manifest
  • MonitoringRoleArn — not selected in manifest
  • PromotionTier — not selected in manifest
  • Timezone — not selected in manifest
  • IAMDatabaseAuthenticationEnabled — not selected in manifest
  • DatabaseInsightsMode — not selected in manifest
  • PerformanceInsightsEnabled — not selected in manifest
  • PerformanceInsightsKMSKeyId — not selected in manifest
  • PerformanceInsightsRetentionPeriod — not selected in manifest
  • EnabledCloudwatchLogsExports — not selected in manifest
  • ProcessorFeatures — not selected in manifest
  • DeletionProtection — not selected in manifest
  • AssociatedRoles — not selected in manifest
  • ListenerEndpoint — not selected in manifest
  • MaxAllocatedStorage — not selected in manifest
  • TagList — not selected in manifest
  • AutomationMode — not selected in manifest
  • ResumeFullAutomationModeTime — not selected in manifest
  • CustomerOwnedIpEnabled — not selected in manifest
  • NetworkType — not selected in manifest
  • ActivityStreamStatus — not selected in manifest
  • ActivityStreamKmsKeyId — not selected in manifest
  • ActivityStreamKinesisStreamName — not selected in manifest
  • ActivityStreamMode — not selected in manifest
  • ActivityStreamEngineNativeAuditFieldsIncluded — not selected in manifest
  • AwsBackupRecoveryPointArn — not selected in manifest
  • DBInstanceAutomatedBackupsReplications — not selected in manifest
  • BackupTarget — not selected in manifest
  • AutomaticRestartTime — not selected in manifest
  • CustomIamInstanceProfile — not selected in manifest
  • ActivityStreamPolicyStatus — not selected in manifest
  • CertificateDetails — not selected in manifest
  • DBSystemId — not selected in manifest
  • MasterUserSecret — not selected in manifest
  • ReadReplicaSourceDBClusterIdentifier — not selected in manifest
  • PercentProgress — not selected in manifest
  • MultiTenant — not selected in manifest
  • DedicatedLogVolume — not selected in manifest
  • IsStorageConfigUpgradeAvailable — not selected in manifest
  • EngineLifecycleSupport — not selected in manifest
  • AdditionalStorageVolumes — not selected in manifest
  • StorageVolumeStatus — not selected in manifest

Fields

db_instance_identifier: Option<String>

The user-supplied database identifier. This identifier is the unique key that identifies a DB instance.

db_instance_class: Option<String>

The name of the compute and memory capacity class of the DB instance.

engine: Option<String>

The database engine used for this DB instance.

db_instance_status: Option<String>

The current state of this database. For information about DB instance statuses, see Viewing DB instance status in the Amazon RDS User Guide.

master_username: Option<String>

The master username for the DB instance.

db_name: Option<String>

The initial database name that you provided (if required) when you created the DB instance. This name is returned for the life of your DB instance. For an RDS for Oracle CDB instance, the name identifies the PDB rather than the CDB.

endpoint: Option<Endpoint>

The connection endpoint for the DB instance. The endpoint might not be shown for instances with the status of creating.

allocated_storage: Option<i32>

The amount of storage in gibibytes (GiB) allocated for the DB instance.

instance_create_time: Option<String>

The date and time when the DB instance was created.

preferred_backup_window: Option<String>

The daily time range during which automated backups are created if automated backups are enabled, as determined by the BackupRetentionPeriod.

backup_retention_period: Option<i32>

The number of days for which automatic DB snapshots are retained.

availability_zone: Option<String>

The name of the Availability Zone where the DB instance is located.

preferred_maintenance_window: Option<String>

The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).

multi_az: Option<bool>

Indicates whether the DB instance is a Multi-AZ deployment. This setting doesn’t apply to RDS Custom DB instances.

engine_version: Option<String>

The version of the database engine.

auto_minor_version_upgrade: Option<bool>

Indicates whether minor version patches are applied automatically. For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.

publicly_accessible: Option<bool>

Indicates whether the DB instance is publicly accessible. When the DB instance is publicly accessible and you connect from outside of the DB instance’s virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB instance, the endpoint resolves to the private IP address. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn’t permitted if the security group assigned to the DB cluster doesn’t permit it. When the DB instance isn’t publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address. For more information, see CreateDBInstance.

storage_type: Option<String>

The storage type associated with the DB instance.

storage_encrypted: Option<bool>

Indicates whether the DB instance is encrypted.

kms_key_id: Option<String>

If StorageEncrypted is enabled, the Amazon Web Services KMS key identifier for the encrypted DB instance. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

dbi_resource_id: Option<String>

The Amazon Web Services Region-unique, immutable identifier for the DB instance. This identifier is found in Amazon Web Services CloudTrail log entries whenever the Amazon Web Services KMS key for the DB instance is accessed.

db_instance_arn: Option<String>

The Amazon Resource Name (ARN) for the DB instance.

iops: Option<i32>

The Provisioned IOPS (I/O operations per second) value for the DB instance.

storage_throughput: Option<i32>

The storage throughput for the DB instance. This setting applies only to the gp3 storage type.