ModifyDBInstanceRequest

Struct ModifyDBInstanceRequest 

pub struct ModifyDBInstanceRequest {
Show 15 fields pub db_instance_identifier: String, pub allocated_storage: Option<i32>, pub db_instance_class: Option<String>, pub apply_immediately: Option<bool>, pub master_user_password: Option<String>, pub backup_retention_period: Option<i32>, pub preferred_backup_window: Option<String>, pub preferred_maintenance_window: Option<String>, pub multi_az: Option<bool>, pub engine_version: Option<String>, pub auto_minor_version_upgrade: Option<bool>, pub iops: Option<i32>, pub storage_type: Option<String>, pub publicly_accessible: Option<bool>, pub storage_throughput: Option<i32>,
}
AWS API: rds.v1.ModifyDBInstanceMessage Reference: https://docs.aws.amazon.com/AmazonRDS/latest/APIReference//ModifyDBInstanceMessage

Coverage

15 of 64 fields included. Omitted fields:

  • DBSubnetGroupName — not selected in manifest
  • DBSecurityGroups — not selected in manifest
  • VpcSecurityGroupIds — not selected in manifest
  • DBParameterGroupName — not selected in manifest
  • AllowMajorVersionUpgrade — not selected in manifest
  • LicenseModel — not selected in manifest
  • OptionGroupName — not selected in manifest
  • NewDBInstanceIdentifier — not selected in manifest
  • TdeCredentialArn — not selected in manifest
  • TdeCredentialPassword — not selected in manifest
  • CACertificateIdentifier — not selected in manifest
  • Domain — not selected in manifest
  • DomainFqdn — not selected in manifest
  • DomainOu — not selected in manifest
  • DomainAuthSecretArn — not selected in manifest
  • DomainDnsIps — not selected in manifest
  • DisableDomain — not selected in manifest
  • CopyTagsToSnapshot — not selected in manifest
  • MonitoringInterval — not selected in manifest
  • DBPortNumber — not selected in manifest
  • MonitoringRoleArn — not selected in manifest
  • DomainIAMRoleName — not selected in manifest
  • PromotionTier — not selected in manifest
  • EnableIAMDatabaseAuthentication — not selected in manifest
  • DatabaseInsightsMode — not selected in manifest
  • EnablePerformanceInsights — not selected in manifest
  • PerformanceInsightsKMSKeyId — not selected in manifest
  • PerformanceInsightsRetentionPeriod — not selected in manifest
  • CloudwatchLogsExportConfiguration — not selected in manifest
  • ProcessorFeatures — not selected in manifest
  • UseDefaultProcessorFeatures — not selected in manifest
  • DeletionProtection — not selected in manifest
  • MaxAllocatedStorage — not selected in manifest
  • CertificateRotationRestart — not selected in manifest
  • ReplicaMode — not selected in manifest
  • AutomationMode — not selected in manifest
  • ResumeFullAutomationModeMinutes — not selected in manifest
  • EnableCustomerOwnedIp — not selected in manifest
  • NetworkType — not selected in manifest
  • AwsBackupRecoveryPointArn — not selected in manifest
  • ManageMasterUserPassword — not selected in manifest
  • RotateMasterUserPassword — not selected in manifest
  • MasterUserSecretKmsKeyId — not selected in manifest
  • MultiTenant — not selected in manifest
  • DedicatedLogVolume — not selected in manifest
  • Engine — not selected in manifest
  • AdditionalStorageVolumes — not selected in manifest
  • TagSpecifications — not selected in manifest
  • MasterUserAuthenticationType — not selected in manifest

Fields

db_instance_identifier: String

The identifier of DB instance to modify. This value is stored as a lowercase string. Constraints: Must match the identifier of an existing DB instance.

allocated_storage: Option<i32>

The new amount of storage in gibibytes (GiB) to allocate for the DB instance. For RDS for Db2, MariaDB, RDS for MySQL, RDS for Oracle, and RDS for PostgreSQL, the value supplied must be at least 10% greater than the current value. Values that are not at least 10% greater than the existing value are rounded up so that they are 10% greater than the current value. For the valid values for allocated storage for each engine, see CreateDBInstance. Constraints: When you increase the allocated storage for a DB instance that uses Provisioned IOPS (gp3, io1, or io2 storage type), you must also specify the Iops parameter. You can use the current value for Iops.

db_instance_class: Option<String>

The new compute and memory capacity of the DB instance, for example db.m4.large. Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines. For the full list of DB instance classes, and availability for your engine, see DB Instance Class in the Amazon RDS User Guide or Aurora DB instance classes in the Amazon Aurora User Guide. For RDS Custom, see DB instance class support for RDS Custom for Oracle and DB instance class support for RDS Custom for SQL Server. If you modify the DB instance class, an outage occurs during the change. The change is applied during the next maintenance window, unless you specify ApplyImmediately in your request. Default: Uses existing setting Constraints: If you are modifying the DB instance class and upgrading the engine version at the same time, the currently running engine version must be supported on the specified DB instance class. Otherwise, the operation returns an error. In this case, first run the operation to upgrade the engine version, and then run it again to modify the DB instance class.

apply_immediately: Option<bool>

Specifies whether the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB instance. By default, this parameter is disabled. If this parameter is disabled, changes to the DB instance are applied during the next maintenance window. Some parameter changes can cause an outage and are applied on the next call to RebootDBInstance, or the next failure reboot. Review the table of parameters in Modifying a DB Instance in the Amazon RDS User Guide to see the impact of enabling or disabling ApplyImmediately for each modified parameter and to determine when the changes are applied.

master_user_password: Option<String>

The new password for the master user. Changing this parameter doesn’t result in an outage and the change is asynchronously applied as soon as possible. Between the time of the request and the completion of the request, the MasterUserPassword element exists in the PendingModifiedValues element of the operation response. Amazon RDS API operations never return the password, so this operation provides a way to regain access to a primary instance user if the password is lost. This includes restoring privileges that might have been accidentally revoked. This setting doesn’t apply to the following DB instances: Amazon Aurora The password for the master user is managed by the DB cluster. For more information, see ModifyDBCluster. RDS Custom RDS for Oracle CDBs in the multi- tenant configuration Specify the master password in ModifyTenantDatabase instead. Default: Uses existing setting Constraints: Can’t be specified if ManageMasterUserPassword is turned on. Can include any printable ASCII character except “/”, “”“, or “@”. For RDS for Oracle, can’t include the “&” (ampersand) or the “’” (single quotes) character. Length Constraints: RDS for Db2

  • Must contain from 8 to 255 characters. RDS for MariaDB
  • Must contain from 8 to 41 characters. RDS for Microsoft SQL Server
  • Must contain from 8 to 128 characters. RDS for MySQL
  • Must contain from 8 to 41 characters. RDS for Oracle
  • Must contain from 8 to 30 characters. RDS for PostgreSQL
  • Must contain from 8 to 128 characters.
backup_retention_period: Option<i32>

The number of days to retain automated backups. Setting this parameter to a positive number enables backups. Setting this parameter to 0 disables automated backups. Enabling and disabling backups can result in a brief I/O suspension that lasts from a few seconds to a few minutes, depending on the size and class of your DB instance. These changes are applied during the next maintenance window unless the ApplyImmediately parameter is enabled for this request. If you change the parameter from one non-zero value to another non-zero value, the change is asynchronously applied as soon as possible. This setting doesn’t apply to Amazon Aurora DB instances. The retention period for automated backups is managed by the DB cluster. For more information, see ModifyDBCluster. Default: Uses existing setting Constraints: Must be a value from 0 to 35. Can’t be set to 0 if the DB instance is a source to read replicas. Can’t be set to 0 for an RDS Custom for Oracle DB instance.

preferred_backup_window: Option<String>

The daily time range during which automated backups are created if automated backups are enabled, as determined by the BackupRetentionPeriod parameter. Changing this parameter doesn’t result in an outage and the change is asynchronously applied as soon as possible. The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region. For more information, see Backup window in the Amazon RDS User Guide. This setting doesn’t apply to Amazon Aurora DB instances. The daily time range for creating automated backups is managed by the DB cluster. For more information, see ModifyDBCluster. Constraints: Must be in the format hh24:mi-hh24:mi. Must be in Universal Coordinated Time (UTC). Must not conflict with the preferred maintenance window. Must be at least 30 minutes.

preferred_maintenance_window: Option<String>

The weekly time range during which system maintenance can occur, which might result in an outage. Changing this parameter doesn’t result in an outage, except in the following situation, and the change is asynchronously applied as soon as possible. If there are pending actions that cause a reboot, and the maintenance window is changed to include the current time, then changing this parameter causes a reboot of the DB instance. If you change this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure pending changes are applied. For more information, see Amazon RDS Maintenance Window in the Amazon RDS User Guide. Default: Uses existing setting Constraints: Must be in the format ddd:hh24:mi-ddd:hh24:mi. The day values must be mon | tue | wed | thu | fri | sat | sun. Must be in Universal Coordinated Time (UTC). Must not conflict with the preferred backup window. Must be at least 30 minutes.

multi_az: Option<bool>

Specifies whether the DB instance is a Multi-AZ deployment. Changing this parameter doesn’t result in an outage. The change is applied during the next maintenance window unless the ApplyImmediately parameter is enabled for this request. This setting doesn’t apply to RDS Custom DB instances.

engine_version: Option<String>

The version number of the database engine to upgrade to. Changing this parameter results in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is enabled for this request. For major version upgrades, if a nondefault DB parameter group is currently in use, a new DB parameter group in the DB parameter group family for the new engine version must be specified. The new DB parameter group can be the default for that DB parameter group family. If you specify only a major version, Amazon RDS updates the DB instance to the default minor version if the current minor version is lower. For information about valid engine versions, see CreateDBInstance, or call DescribeDBEngineVersions. If the instance that you’re modifying is acting as a read replica, the engine version that you specify must be the same or higher than the version that the source DB instance or cluster is running. In RDS Custom for Oracle, this parameter is supported for read replicas only if they are in the PATCH_DB_FAILURE lifecycle. Constraints: If you are upgrading the engine version and modifying the DB instance class at the same time, the currently running engine version must be supported on the specified DB instance class. Otherwise, the operation returns an error. In this case, first run the operation to upgrade the engine version, and then run it again to modify the DB instance class.

auto_minor_version_upgrade: Option<bool>

Specifies whether minor version upgrades are applied automatically to the DB instance during the maintenance window. An outage occurs when all the following conditions are met: The automatic upgrade is enabled for the maintenance window. A newer minor version is available. RDS has enabled automatic patching for the engine version. If any of the preceding conditions isn’t met, Amazon RDS applies the change as soon as possible and doesn’t cause an outage. For an RDS Custom DB instance, don’t enable this setting. Otherwise, the operation returns an error. For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.

iops: Option<i32>

The new Provisioned IOPS (I/O operations per second) value for the RDS instance. Changing this setting doesn’t result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is enabled for this request. If you are migrating from Provisioned IOPS to standard storage, set this value to 0. The DB instance will require a reboot for the change in storage type to take effect. If you choose to migrate your DB instance from using standard storage to Provisioned IOPS (io1), or from Provisioned IOPS to standard storage, the process can take time. The duration of the migration depends on several factors such as database load, storage size, storage type (standard or Provisioned IOPS), amount of IOPS provisioned (if any), and the number of prior scale storage operations. Typical migration times are under 24 hours, but the process can take up to several days in some cases. During the migration, the DB instance is available for use, but might experience performance degradation. While the migration takes place, nightly backups for the instance are suspended. No other Amazon RDS operations can take place for the instance, including modifying the instance, rebooting the instance, deleting the instance, creating a read replica for the instance, and creating a DB snapshot of the instance. Constraints: For RDS for MariaDB, RDS for MySQL, RDS for Oracle, and RDS for PostgreSQL

  • The value supplied must be at least 10% greater than the current value. Values that are not at least 10% greater than the existing value are rounded up so that they are 10% greater than the current value. When you increase the Provisioned IOPS, you must also specify the AllocatedStorage parameter. You can use the current value for AllocatedStorage. Default: Uses existing setting
storage_type: Option<String>

The storage type to associate with the DB instance. If you specify io1, io2, or gp3 you must also include a value for the Iops parameter. If you choose to migrate your DB instance from using standard storage to gp2 (General Purpose SSD), gp3, or Provisioned IOPS (io1), or from these storage types to standard storage, the process can take time. The duration of the migration depends on several factors such as database load, storage size, storage type (standard or Provisioned IOPS), amount of IOPS provisioned (if any), and the number of prior scale storage operations. Typical migration times are under 24 hours, but the process can take up to several days in some cases. During the migration, the DB instance is available for use, but might experience performance degradation. While the migration takes place, nightly backups for the instance are suspended. No other Amazon RDS operations can take place for the instance, including modifying the instance, rebooting the instance, deleting the instance, creating a read replica for the instance, and creating a DB snapshot of the instance. Valid Values: gp2 | gp3 | io1 | io2 | standard Default: io1, if the Iops parameter is specified. Otherwise, gp2.

publicly_accessible: Option<bool>

Specifies whether the DB instance is publicly accessible. When the DB instance is publicly accessible and you connect from outside of the DB instance’s virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB instance, the endpoint resolves to the private IP address. Access to the DB instance is ultimately controlled by the security group it uses. That public access isn’t permitted if the security group assigned to the DB instance doesn’t permit it. When the DB instance isn’t publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address. PubliclyAccessible only applies to DB instances in a VPC. The DB instance must be part of a public subnet and PubliclyAccessible must be enabled for it to be publicly accessible. Changes to the PubliclyAccessible parameter are applied immediately regardless of the value of the ApplyImmediately parameter.

storage_throughput: Option<i32>

The storage throughput value for the DB instance. This setting applies only to the gp3 storage type. This setting doesn’t apply to Amazon Aurora or RDS Custom DB instances.