pub struct DescribeClustersResponse {
pub clusters: Vec<Cluster>,
pub marker: Option<String>,
}Expand description
Contains the output from the DescribeClusters action.
AWS API: redshift.v1.ClustersMessage
Reference: https://docs.aws.amazon.com/redshift/latest/APIReference//ClustersMessage
Fields
clusters: Vec<Cluster>A list of Cluster objects, where each object describes one cluster.
marker: Option<String>A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.