CreateHealthCheckRequest

Struct CreateHealthCheckRequest 

pub struct CreateHealthCheckRequest {
    pub caller_reference: String,
    pub health_check_config: HealthCheckConfig,
}
A complex type that contains the health check request information.

AWS API: route53.v1.CreateHealthCheckRequest

Fields

caller_reference: String

A unique string that identifies the request and that allows you to retry a failed CreateHealthCheck request without the risk of creating two identical health checks: If you send a CreateHealthCheck request with the same CallerReference and settings as a previous request, and if the health check doesn’t exist, Amazon Route 53 creates the health check. If the health check does exist, Route 53 returns the health check configuration in the response. If you send a CreateHealthCheck request with the same CallerReference as a deleted health check, regardless of the settings, Route 53 returns a HealthCheckAlreadyExists error. If you send a CreateHealthCheck request with the same CallerReference as an existing health check but with different settings, Route 53 returns a HealthCheckAlreadyExists error. If you send a CreateHealthCheck request with a unique CallerReference but settings identical to an existing health check, Route 53 creates the health check. Route 53 does not store the CallerReference for a deleted health check indefinitely. The CallerReference for a deleted health check will be deleted after a number of days.

health_check_config: HealthCheckConfig

A complex type that contains settings for a new health check.