pub struct CreateHealthCheckResponse {
pub health_check: HealthCheck,
}Expand description
A complex type containing the response information for the new health check.
AWS API: route53.v1.CreateHealthCheckResponse
Coverage
1 of 2 fields included. Omitted fields:
Location— not selected in manifest
Fields
health_check: HealthCheckA complex type that contains identifying information about the health check.