pub struct GetHealthCheckStatusResponse {
pub health_check_observations: Vec<HealthCheckObservation>,
}Expand description
A complex type that contains the response to a GetHealthCheck request.
AWS API: route53.v1.GetHealthCheckStatusResponse
Fields
health_check_observations: Vec<HealthCheckObservation>A list that contains one HealthCheckObservation element for each Amazon Route 53 health checker that is reporting a status about the health check endpoint.