HealthCheckConfig

Struct HealthCheckConfig 

pub struct HealthCheckConfig {
    pub type: Option<HealthCheckType>,
    pub ip_address: Option<String>,
    pub port: Option<i32>,
    pub fully_qualified_domain_name: Option<String>,
    pub resource_path: Option<String>,
    pub request_interval: Option<i32>,
    pub failure_threshold: Option<i32>,
}
A complex type that contains information about the health check.

AWS API: route53.v1.HealthCheckConfig

Coverage

7 of 18 fields included. Omitted fields:

  • SearchString — not selected in manifest
  • MeasureLatency — not selected in manifest
  • Inverted — not selected in manifest
  • Disabled — not selected in manifest
  • HealthThreshold — not selected in manifest
  • ChildHealthChecks — not selected in manifest
  • EnableSNI — not selected in manifest
  • Regions — not selected in manifest
  • AlarmIdentifier — not selected in manifest
  • InsufficientDataHealthStatus — not selected in manifest
  • RoutingControlArn — not selected in manifest

Fields

type: Option<HealthCheckType>

The type of health check that you want to create, which indicates how Amazon Route 53 determines whether an endpoint is healthy. You can’t change the value of Type after you create a health check. You can create the following types of health checks: HTTP: Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTP request and waits for an HTTP status code of 200 or greater and less than 400. HTTPS: Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTPS request and waits for an HTTP status code of 200 or greater and less than 400. If you specify HTTPS for the value of Type, the endpoint must support TLS v1.0, v1.1, or v1.2. HTTP_STR_MATCH: Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTP request and searches the first 5,120 bytes of the response body for the string that you specify in SearchString. HTTPS_STR_MATCH: Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTPS request and searches the first 5,120 bytes of the response body for the string that you specify in SearchString. TCP: Route 53 tries to establish a TCP connection. CLOUDWATCH_METRIC: The health check is associated with a CloudWatch alarm. If the state of the alarm is OK, the health check is considered healthy. If the state is ALARM, the health check is considered unhealthy. If CloudWatch doesn’t have sufficient data to determine whether the state is OK or ALARM, the health check status depends on the setting for InsufficientDataHealthStatus: Healthy, Unhealthy, or LastKnownStatus. CALCULATED: For health checks that monitor the status of other health checks, Route 53 adds up the number of health checks that Route 53 health checkers consider to be healthy and compares that number with the value of HealthThreshold. RECOVERY_CONTROL: The health check is associated with a Route53 Application Recovery Controller routing control. If the routing control state is ON, the health check is considered healthy. If the state is OFF, the health check is considered unhealthy. For more information, see How Route 53 Determines Whether an Endpoint Is Healthy in the Amazon Route 53 Developer Guide.

ip_address: Option<String>

The IPv4 or IPv6 IP address of the endpoint that you want Amazon Route 53 to perform health checks on. If you don’t specify a value for IPAddress, Route 53 sends a DNS request to resolve the domain name that you specify in FullyQualifiedDomainName at the interval that you specify in RequestInterval. Using an IP address returned by DNS, Route 53 then checks the health of the endpoint. Use one of the following formats for the value of IPAddress: IPv4 address: four values between 0 and 255, separated by periods (.), for example, 192.0.2.44. IPv6 address: eight groups of four hexadecimal values, separated by colons (:), for example, 2001:0db8:85a3:0000:0000:abcd:0001:2345. You can also shorten IPv6 addresses as described in RFC 5952, for example, 2001:db8:85a3::abcd:1:2345. If the endpoint is an EC2 instance, we recommend that you create an Elastic IP address, associate it with your EC2 instance, and specify the Elastic IP address for IPAddress. This ensures that the IP address of your instance will never change. For more information, see FullyQualifiedDomainName. Constraints: Route 53 can’t check the health of endpoints for which the IP address is in local, private, non- routable, or multicast ranges. For more information about IP addresses for which you can’t create health checks, see the following documents: RFC 5735, Special Use IPv4 Addresses RFC 6598, IANA-Reserved IPv4 Prefix for Shared Address Space RFC 5156, Special-Use IPv6 Addresses When the value of Type is CALCULATED or CLOUDWATCH_METRIC, omit IPAddress.

port: Option<i32>

The port on the endpoint that you want Amazon Route 53 to perform health checks on. Don’t specify a value for Port when you specify a value for Type of CLOUDWATCH_METRIC or CALCULATED.

fully_qualified_domain_name: Option<String>

Amazon Route 53 behavior depends on whether you specify a value for IPAddress. If you specify a value for IPAddress: Amazon Route 53 sends health check requests to the specified IPv4 or IPv6 address and passes the value of FullyQualifiedDomainName in the Host header for all health checks except TCP health checks. This is typically the fully qualified DNS name of the endpoint on which you want Route 53 to perform health checks. When Route 53 checks the health of an endpoint, here is how it constructs the Host header: If you specify a value of 80 for Port and HTTP or HTTP_STR_MATCH for Type, Route 53 passes the value of FullyQualifiedDomainName to the endpoint in the Host header. If you specify a value of 443 for Port and HTTPS or HTTPS_STR_MATCH for Type, Route 53 passes the value of FullyQualifiedDomainName to the endpoint in the Host header. If you specify another value for Port and any value except TCP for Type, Route 53 passes FullyQualifiedDomainName:Port to the endpoint in the Host header. If you don’t specify a value for FullyQualifiedDomainName, Route 53 substitutes the value of IPAddress in the Host header in each of the preceding cases. If you don’t specify a value for IPAddress: Route 53 sends a DNS request to the domain that you specify for FullyQualifiedDomainName at the interval that you specify for RequestInterval. Using an IPv4 address that DNS returns, Route 53 then checks the health of the endpoint. If you don’t specify a value for IPAddress, Route 53 uses only IPv4 to send health checks to the endpoint. If there’s no resource record set with a type of A for the name that you specify for FullyQualifiedDomainName, the health check fails with a “DNS resolution failed” error. If you want to check the health of weighted, latency, or failover resource record sets and you choose to specify the endpoint only by FullyQualifiedDomainName, we recommend that you create a separate health check for each endpoint. For example, create a health check for each HTTP server that is serving content for www.example.com. For the value of FullyQualifiedDomainName, specify the domain name of the server (such as us- east-2-www.example.com), not the name of the resource record sets (www.example.com). In this configuration, if you create a health check for which the value of FullyQualifiedDomainName matches the name of the resource record sets and you then associate the health check with those resource record sets, health check results will be unpredictable. In addition, if the value that you specify for Type is HTTP, HTTPS, HTTP_STR_MATCH, or HTTPS_STR_MATCH, Route 53 passes the value of FullyQualifiedDomainName in the Host header, as it does when you specify a value for IPAddress. If the value of Type is TCP, Route 53 doesn’t pass a Host header.

resource_path: Option<String>

The path, if any, that you want Amazon Route 53 to request when performing health checks. The path can be any value for which your endpoint will return an HTTP status code of 2xx or 3xx when the endpoint is healthy, for example, the file /docs/route53-health-check.html. You can also include query string parameters, for example, /welcome.html?language=jp&login=y.

request_interval: Option<i32>

The number of seconds between the time that Amazon Route 53 gets a response from your endpoint and the time that it sends the next health check request. Each Route 53 health checker makes requests at this interval. RequestInterval is not supported when you specify a value for Type of RECOVERY_CONTROL. You can’t change the value of RequestInterval after you create a health check. If you don’t specify a value for RequestInterval, the default value is 30 seconds.

failure_threshold: Option<i32>

The number of consecutive health checks that an endpoint must pass or fail for Amazon Route 53 to change the current status of the endpoint from unhealthy to healthy or vice versa. For more information, see How Amazon Route 53 Determines Whether an Endpoint Is Healthy in the Amazon Route 53 Developer Guide. FailureThreshold is not supported when you specify a value for Type of RECOVERY_CONTROL. Otherwise, if you don’t specify a value for FailureThreshold, the default value is three health checks.