pub struct DynamodbClient<'a> { /* private fields */ }Expand description
Client for the Amazon DynamoDB API
Implementations
Sourceimpl<'a> DynamodbClient<'a>
impl<'a> DynamodbClient<'a>
Sourcepub async fn list_tables(
&self,
body: &ListTablesInput,
) -> Result<ListTablesOutput>
pub async fn list_tables( &self, body: &ListTablesInput, ) -> Result<ListTablesOutput>
Returns an array of table names associated with the current account and endpoint.
Sourcepub async fn describe_table(
&self,
body: &DescribeTableInput,
) -> Result<DescribeTableOutput>
pub async fn describe_table( &self, body: &DescribeTableInput, ) -> Result<DescribeTableOutput>
Returns information about the table, including the current status of the table, when it was created, the primary key sch
Sourcepub async fn update_table(
&self,
body: &UpdateTableInput,
) -> Result<UpdateTableOutput>
pub async fn update_table( &self, body: &UpdateTableInput, ) -> Result<UpdateTableOutput>
Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table.
Sourcepub async fn delete_table(
&self,
body: &DeleteTableInput,
) -> Result<DeleteTableOutput>
pub async fn delete_table( &self, body: &DeleteTableInput, ) -> Result<DeleteTableOutput>
The DeleteTable operation deletes a table and all of its items.