pub struct TableDescription {Show 16 fields
pub table_name: Option<String>,
pub table_arn: Option<String>,
pub table_id: Option<String>,
pub table_status: Option<String>,
pub creation_date_time: Option<f64>,
pub item_count: Option<i64>,
pub table_size_bytes: Option<i64>,
pub billing_mode_summary: Option<BillingModeSummary>,
pub provisioned_throughput: Option<ProvisionedThroughputDescription>,
pub key_schema: Vec<KeySchemaElement>,
pub attribute_definitions: Vec<AttributeDefinition>,
pub stream_specification: Option<StreamSpecification>,
pub sse_description: Option<SSEDescription>,
pub table_class_summary: Option<TableClassSummary>,
pub deletion_protection_enabled: Option<bool>,
pub archival_summary: Option<ArchivalSummary>,
}Expand description
Represents the properties of a table.
AWS API: dynamodb.v1.TableDescription
Reference: https://docs.aws.amazon.com/amazondynamodb/latest/APIReference//TableDescription
Coverage
16 of 28 fields included. Omitted fields:
LocalSecondaryIndexes— not selected in manifestGlobalSecondaryIndexes— not selected in manifestLatestStreamLabel— not selected in manifestLatestStreamArn— not selected in manifestGlobalTableVersion— not selected in manifestReplicas— not selected in manifestGlobalTableWitnesses— not selected in manifestGlobalTableSettingsReplicationMode— not selected in manifestRestoreSummary— not selected in manifestOnDemandThroughput— not selected in manifestWarmThroughput— not selected in manifestMultiRegionConsistency— not selected in manifest
Fields
table_name: Option<String>The name of the table.
table_arn: Option<String>The Amazon Resource Name (ARN) that uniquely identifies the table.
table_id: Option<String>Unique identifier for the table for which the backup was created.
table_status: Option<String>The current state of the table: CREATING
- The table is being created. UPDATING
- The table/index configuration is being updated. The table/index remains available for data operations when UPDATING. DELETING
- The table is being deleted. ACTIVE
- The table is ready for use. INACCESSIBLE_ENCRYPTION_CREDENTIALS
- The KMS key used to encrypt the table in inaccessible. Table operations may fail due to failure to use the KMS key. DynamoDB will initiate the table archival process when a table’s KMS key remains inaccessible for more than seven days. ARCHIVING
- The table is being archived. Operations are not allowed until archival is complete. ARCHIVED
- The table has been archived. See the ArchivalReason for more information.
creation_date_time: Option<f64>The date and time when the table was created, in UNIX epoch time format.
item_count: Option<i64>The number of items in the specified table. DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
table_size_bytes: Option<i64>The total size of the specified table, in bytes. DynamoDB updates this value approximately every six hours. Recent changes might not be reflected in this value.
billing_mode_summary: Option<BillingModeSummary>Contains the details for the read/write capacity mode.
provisioned_throughput: Option<ProvisionedThroughputDescription>The provisioned throughput settings for the table, consisting of read and write capacity units, along with data about increases and decreases.
key_schema: Vec<KeySchemaElement>The primary key structure for the table. Each KeySchemaElement consists of: AttributeName
- The name of the attribute. KeyType
- The role of the attribute: HASH
- partition key RANGE
- sort key The partition key of an item is also known as its hash attribute. The term “hash attribute” derives from DynamoDB’s usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values. The sort key of an item is also known as its range attribute. The term “range attribute” derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value. For more information about primary keys, see Primary Key in the Amazon DynamoDB Developer Guide.
attribute_definitions: Vec<AttributeDefinition>An array of AttributeDefinition objects. Each of these objects describes one attribute in the table and index key schema. Each AttributeDefinition object in this array is composed of: AttributeName
- The name of the attribute. AttributeType
- The data type for the attribute.
stream_specification: Option<StreamSpecification>The current DynamoDB Streams configuration for the table.
sse_description: Option<SSEDescription>The description of the server-side encryption status on the specified table.
table_class_summary: Option<TableClassSummary>Contains details of the table class.
deletion_protection_enabled: Option<bool>Indicates whether deletion protection is enabled (true) or disabled (false) on the table.
archival_summary: Option<ArchivalSummary>Contains information about the table archive.