pub struct DescribeFlowLogsRequest {
pub flow_log_ids: Vec<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Expand description
AWS API: ec2.v1.DescribeFlowLogsRequest
Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//DescribeFlowLogsRequest
Coverage
3 of 5 fields included. Omitted fields:
DryRun— not selected in manifestFilter— not selected in manifest
Fields
flow_log_ids: Vec<String>One or more flow log IDs. Constraint: Maximum of 1000 flow log IDs.
next_token: Option<String>The token to request the next page of items. Pagination continues from the end of the items returned by the previous request.
max_results: Option<i32>The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.