pub struct ModifyInstanceMetadataOptionsRequest {
pub instance_id: String,
pub http_tokens: Option<String>,
pub http_endpoint: Option<String>,
}Expand description
AWS API: ec2.v1.ModifyInstanceMetadataOptionsRequest
Reference: https://docs.aws.amazon.com/AWSEC2/latest/APIReference//ModifyInstanceMetadataOptionsRequest
Coverage
3 of 7 fields included. Omitted fields:
HttpPutResponseHopLimit— not selected in manifestDryRun— not selected in manifestHttpProtocolIpv6— not selected in manifestInstanceMetadataTags— not selected in manifest
Fields
instance_id: StringThe ID of the instance.
http_tokens: Option<String>Indicates whether IMDSv2 is required. optional
- IMDSv2 is optional. You can choose whether to send a session token in your instance metadata retrieval requests. If you retrieve IAM role credentials without a session token, you receive the IMDSv1 role credentials. If you retrieve IAM role credentials using a valid session token, you receive the IMDSv2 role credentials. required
- IMDSv2 is required. You must send a session token in your instance metadata retrieval requests. With this option, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available. Default: If the value of ImdsSupport for the Amazon Machine Image (AMI) for your instance is v2.0 and the account level default is set to no-preference, the default is required. If the value of ImdsSupport for the Amazon Machine Image (AMI) for your instance is v2.0, but the account level default is set to V1 or V2, the default is optional. The default value can also be affected by other combinations of parameters. For more information, see Order of precedence for instance metadata options in the Amazon EC2 User Guide.
http_endpoint: Option<String>Enables or disables the HTTP metadata endpoint on your instances. If this parameter is not specified, the existing state is maintained. If you specify a value of disabled, you cannot access your instance metadata.