pub struct TaskDefinition {Show 14 fields
pub task_definition_arn: Option<String>,
pub container_definitions: Vec<ContainerDefinition>,
pub family: Option<String>,
pub task_role_arn: Option<String>,
pub execution_role_arn: Option<String>,
pub network_mode: Option<String>,
pub revision: Option<i32>,
pub status: Option<String>,
pub compatibilities: Vec<String>,
pub requires_compatibilities: Vec<String>,
pub cpu: Option<String>,
pub memory: Option<String>,
pub registered_at: Option<f64>,
pub deregistered_at: Option<f64>,
}Expand description
The details of a task definition which describes the container and volume definitions of an Amazon Elastic Container Service task. You can specify which Docker images to use, the required resources, and other configurations related to launching the task definition through an Amazon ECS service or task.
AWS API: ecs.v1.TaskDefinition
Reference: https://docs.aws.amazon.com/AmazonECS/latest/APIReference//TaskDefinition
Coverage
14 of 25 fields included. Omitted fields:
volumes— not selected in manifestrequiresAttributes— not selected in manifestplacementConstraints— not selected in manifestruntimePlatform— not selected in manifestinferenceAccelerators— not selected in manifestpidMode— not selected in manifestipcMode— not selected in manifestproxyConfiguration— not selected in manifestregisteredBy— not selected in manifestephemeralStorage— not selected in manifestenableFaultInjection— not selected in manifest
Fields
task_definition_arn: Option<String>The full Amazon Resource Name (ARN) of the task definition.
container_definitions: Vec<ContainerDefinition>A list of container definitions in JSON format that describe the different containers that make up your task. For more information about container definition parameters and defaults, see Amazon ECS Task Definitions in the Amazon Elastic Container Service Developer Guide.
family: Option<String>The name of a family that this task definition is registered to. Up to 255 characters are allowed. Letters (both uppercase and lowercase letters), numbers, hyphens (-), and underscores (_) are allowed. A family groups multiple versions of a task definition. Amazon ECS gives the first task definition that you registered to a family a revision number of 1. Amazon ECS gives sequential revision numbers to each task definition that you add.
task_role_arn: Option<String>The short name or full Amazon Resource Name (ARN) of the Identity and Access Management role that grants containers in the task permission to call Amazon Web Services APIs on your behalf. For informationabout the required IAM roles for Amazon ECS, see IAM roles for Amazon ECS in the Amazon Elastic Container Service Developer Guide.
execution_role_arn: Option<String>The Amazon Resource Name (ARN) of the task execution role that grants the Amazon ECS container agent permission to make Amazon Web Services API calls on your behalf. For informationabout the required IAM roles for Amazon ECS, see IAM roles for Amazon ECS in the Amazon Elastic Container Service Developer Guide.
network_mode: Option<String>The Docker networking mode to use for the containers in the task. The valid values are none, bridge, awsvpc, and host. If no network mode is specified, the default is bridge. For Amazon ECS tasks on Fargate, the awsvpc network mode is required. For Amazon ECS tasks on Amazon EC2 Linux instances, any network mode can be used. For Amazon ECS tasks on Amazon EC2 Windows instances, <default> or awsvpc can be used. If the network mode is set to none, you cannot specify port mappings in your container definitions, and the tasks containers do not have external connectivity. The host and awsvpc network modes offer the highest networking performance for containers because they use the EC2 network stack instead of the virtualized network stack provided by the bridge mode. With the host and awsvpc network modes, exposed container ports are mapped directly to the corresponding host port (for the host network mode) or the attached elastic network interface port (for the awsvpc network mode), so you cannot take advantage of dynamic host port mappings. When using the host network mode, you should not run containers using the root user (UID 0). It is considered best practice to use a non-root user. If the network mode is awsvpc, the task is allocated an elastic network interface, and you must specify a NetworkConfiguration value when you create a service or run a task with the task definition. For more information, see Task Networking in the Amazon Elastic Container Service Developer Guide. If the network mode is host, you cannot run multiple instantiations of the same task on a single container instance when port mappings are used.
revision: Option<i32>The revision of the task in a particular family. The revision is a version number of a task definition in a family. When you register a task definition for the first time, the revision is 1. Each time that you register a new revision of a task definition in the same family, the revision value always increases by one. This is even if you deregistered previous revisions in this family.
status: Option<String>The status of the task definition.
compatibilities: Vec<String>Amazon ECS validates the task definition parameters with those supported by the launch type. For more information, see Amazon ECS launch types in the Amazon Elastic Container Service Developer Guide.
requires_compatibilities: Vec<String>The task launch types the task definition was validated against. The valid values are MANAGED_INSTANCES, EC2, FARGATE, and EXTERNAL. For more information, see Amazon ECS launch types in the Amazon Elastic Container Service Developer Guide.
cpu: Option<String>The number of cpu units used by the task. If you use the EC2 launch type, this field is optional. Any value can be used. If you use the Fargate launch type, this field is required. You must use one of the following values. The value that you choose determines your range of valid values for the memory parameter. If you’re using the EC2 launch type or the external launch type, this field is optional. Supported values are between 128 CPU units (0.125 vCPUs) and 196608 CPU units (192 vCPUs). This field is required for Fargate. For information about the valid values, see Task size in the Amazon Elastic Container Service Developer Guide.
memory: Option<String>The amount (in MiB) of memory used by the task. If your tasks runs on Amazon EC2 instances, you must specify either a task-level memory value or a container-level memory value. This field is optional and any value can be used. If a task-level memory value is specified, the container-level memory value is optional. For more information regarding container-level memory and memory reservation, see ContainerDefinition. If your tasks runs on Fargate, this field is required. You must use one of the following values. The value you choose determines your range of valid values for the cpu parameter. 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB)
- Available cpu values: 256 (.25 vCPU) 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB)
- Available cpu values: 512 (.5 vCPU) 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB)
- Available cpu values: 1024 (1 vCPU) Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
- Available cpu values: 2048 (2 vCPU) Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
- Available cpu values: 4096 (4 vCPU) Between 16 GB and 60 GB in 4 GB increments
- Available cpu values: 8192 (8 vCPU) This option requires Linux platform 1.4.0 or later. Between 32GB and 120 GB in 8 GB increments
- Available cpu values: 16384 (16 vCPU) This option requires Linux platform 1.4.0 or later.
registered_at: Option<f64>The Unix timestamp for the time when the task definition was registered.
deregistered_at: Option<f64>The Unix timestamp for the time when the task definition was deregistered.