FileSystemDescription

Struct FileSystemDescription 

pub struct FileSystemDescription {
    pub owner_id: String,
    pub file_system_id: String,
    pub file_system_arn: Option<String>,
    pub creation_time: String,
    pub life_cycle_state: String,
    pub name: Option<String>,
    pub number_of_mount_targets: i32,
    pub performance_mode: String,
    pub encrypted: Option<bool>,
    pub kms_key_id: Option<String>,
    pub throughput_mode: Option<String>,
    pub tags: Vec<Tag>,
}
A description of the file system.

AWS API: efs.v1.FileSystemDescription Reference: https://docs.aws.amazon.com/efs/latest/ug/API_Operations.html/FileSystemDescription

Coverage

12 of 18 fields included. Omitted fields:

  • CreationToken — not selected in manifest
  • SizeInBytes — not selected in manifest
  • ProvisionedThroughputInMibps — not selected in manifest
  • AvailabilityZoneName — not selected in manifest
  • AvailabilityZoneId — not selected in manifest
  • FileSystemProtection — not selected in manifest

Fields

owner_id: String

The Amazon Web Services account that created the file system.

file_system_id: String

The ID of the file system, assigned by Amazon EFS.

file_system_arn: Option<String>

The Amazon Resource Name (ARN) for the EFS file system, in the format arn:aws:elasticfilesystem:region:account-id:file-system/file-system-id . Example with sample data: arn:aws:elasticfilesystem:us-west-2:1111333322228888:file- system/fs-01234567

creation_time: String

The time that the file system was created, in seconds (since 1970-01-01T00:00:00Z).

life_cycle_state: String

The lifecycle phase of the file system.

name: Option<String>

You can add tags to a file system, including a Name tag. For more information, see CreateFileSystem. If the file system has a Name tag, Amazon EFS returns the value in this field.

number_of_mount_targets: i32

The current number of mount targets that the file system has. For more information, see CreateMountTarget.

performance_mode: String

The performance mode of the file system.

encrypted: Option<bool>

A Boolean value that, if true, indicates that the file system is encrypted.

kms_key_id: Option<String>

The ID of an KMS key used to protect the encrypted file system.

throughput_mode: Option<String>

Displays the file system’s throughput mode. For more information, see Throughput modes in the Amazon EFS User Guide.

tags: Vec<Tag>

The tags associated with the file system, presented as an array of Tag objects.