pub struct NodegroupUpdateConfig {
pub max_unavailable: Option<i32>,
pub max_unavailable_percentage: Option<i32>,
}Expand description
The node group update configuration. An Amazon EKS managed node group updates by replacing nodes with new nodes of newer AMI versions in parallel. You choose the maximum unavailable and the update strategy.
AWS API: eks.v1.NodegroupUpdateConfig
Reference: https://docs.aws.amazon.com/eks/latest/APIReference//NodegroupUpdateConfig
Coverage
2 of 3 fields included. Omitted fields:
updateStrategy— not selected in manifest
Fields
The maximum number of nodes unavailable at once during a version update. Nodes are updated in parallel. This value or maxUnavailablePercentage is required to have a value.The maximum number is 100.
The maximum percentage of nodes unavailable during a version update. This percentage of nodes are updated in parallel, up to 100 nodes at once. This value or maxUnavailable is required to have a value.