Types for the AWS Lambda API (v1).
Auto-generated from the AWS Botocore Model. Do not edit manually — modify the manifest and re-run codegen.
Structs
- Environment
Response - The results of an operation to update or read environment variables. If the operation succeeds, the response contains the environment variables. If it fails, the response contains details about the error.
- Function
Configuration - Details about a function’s configuration.
- GetFunction
Configuration Request - AWS API:
lambda.v1.GetFunctionConfigurationRequest - List
Functions Request - AWS API:
lambda.v1.ListFunctionsRequest - List
Functions Response - A list of Lambda functions.
- Update
Function Configuration Request - AWS API:
lambda.v1.UpdateFunctionConfigurationRequest - VpcConfig
Response - The VPC security groups and subnets that are attached to a Lambda function.