pub struct FunctionConfiguration {
pub function_name: String,
pub function_arn: String,
pub runtime: Option<String>,
pub handler: Option<String>,
pub code_size: Option<i64>,
pub description: Option<String>,
pub timeout: Option<i32>,
pub memory_size: Option<i32>,
pub last_modified: Option<String>,
pub environment: Option<Option<EnvironmentResponse>>,
pub vpc_config: Option<Option<VpcConfigResponse>>,
pub architectures: Vec<String>,
}Expand description
Details about a function’s configuration.
AWS API: lambda.v1.FunctionConfiguration
Coverage
12 of 40 fields included. Omitted fields:
Role— not selected in manifestCodeSha256— not selected in manifestVersion— not selected in manifestDeadLetterConfig— not selected in manifestKMSKeyArn— not selected in manifestTracingConfig— not selected in manifestMasterArn— not selected in manifestRevisionId— not selected in manifestLayers— not selected in manifestState— not selected in manifestStateReason— not selected in manifestStateReasonCode— not selected in manifestLastUpdateStatus— not selected in manifestLastUpdateStatusReason— not selected in manifestLastUpdateStatusReasonCode— not selected in manifestFileSystemConfigs— not selected in manifestPackageType— not selected in manifestImageConfigResponse— not selected in manifestSigningProfileVersionArn— not selected in manifestSigningJobArn— not selected in manifestEphemeralStorage— not selected in manifestSnapStart— not selected in manifestRuntimeVersionConfig— not selected in manifestLoggingConfig— not selected in manifestCapacityProviderConfig— not selected in manifestConfigSha256— not selected in manifestDurableConfig— not selected in manifestTenancyConfig— not selected in manifest
Fields
function_name: StringThe name of the function.
function_arn: StringThe function’s Amazon Resource Name (ARN).
runtime: Option<String>The identifier of the function’s runtime. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you’re deploying a function using a container image. The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation. For a list of all currently supported runtimes, see Supported runtimes.
handler: Option<String>The function that Lambda calls to begin running your function.
code_size: Option<i64>The size of the function’s deployment package, in bytes.
description: Option<String>The function’s description.
timeout: Option<i32>The amount of time in seconds that Lambda allows a function to run before stopping it.
memory_size: Option<i32>The amount of memory available to the function at runtime.
last_modified: Option<String>The date and time that the function was last updated, in ISO-8601 format (YYYY-MM- DDThh:mm:ss.sTZD).
environment: Option<Option<EnvironmentResponse>>The function’s environment variables. Omitted from CloudTrail logs.
vpc_config: Option<Option<VpcConfigResponse>>The function’s networking configuration.
architectures: Vec<String>The instruction set architecture that the function supports. Architecture is a string array with one of the valid values. The default architecture value is x86_64.