pub struct UpdateFunctionConfigurationRequest {
pub function_name: String,
pub timeout: Option<i32>,
pub memory_size: Option<i32>,
pub runtime: Option<String>,
}Expand description
AWS API: lambda.v1.UpdateFunctionConfigurationRequest
Coverage
4 of 21 fields included. Omitted fields:
Role— not selected in manifestHandler— not selected in manifestDescription— not selected in manifestVpcConfig— not selected in manifestEnvironment— not selected in manifestDeadLetterConfig— not selected in manifestKMSKeyArn— not selected in manifestTracingConfig— not selected in manifestRevisionId— not selected in manifestLayers— not selected in manifestFileSystemConfigs— not selected in manifestImageConfig— not selected in manifestEphemeralStorage— not selected in manifestSnapStart— not selected in manifestLoggingConfig— not selected in manifestCapacityProviderConfig— not selected in manifestDurableConfig— not selected in manifest
Fields
function_name: StringThe name or ARN of the Lambda function. Name formats Function name – my-function. Function ARN – arn:aws:lambda:us-west-2:123456789012:function:my-function. Partial ARN – 123456789012:function:my-function. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
timeout: Option<i32>The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see Lambda execution environment.
memory_size: Option<i32>The amount of memory available to the function at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB.
runtime: Option<String>The identifier of the function’s runtime. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you’re deploying a function using a container image. The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation. For a list of all currently supported runtimes, see Supported runtimes.