pub struct DBInstance {Show 24 fields
pub db_instance_identifier: Option<String>,
pub db_instance_class: Option<String>,
pub engine: Option<String>,
pub db_instance_status: Option<String>,
pub master_username: Option<String>,
pub db_name: Option<String>,
pub endpoint: Option<Endpoint>,
pub allocated_storage: Option<i32>,
pub instance_create_time: Option<String>,
pub preferred_backup_window: Option<String>,
pub backup_retention_period: Option<i32>,
pub availability_zone: Option<String>,
pub preferred_maintenance_window: Option<String>,
pub multi_az: Option<bool>,
pub engine_version: Option<String>,
pub auto_minor_version_upgrade: Option<bool>,
pub publicly_accessible: Option<bool>,
pub storage_type: Option<String>,
pub storage_encrypted: Option<bool>,
pub kms_key_id: Option<String>,
pub dbi_resource_id: Option<String>,
pub db_instance_arn: Option<String>,
pub iops: Option<i32>,
pub storage_throughput: Option<i32>,
}Expand description
Contains the details of an Amazon RDS DB instance. This data type is used as a response element in the operations CreateDBInstance, CreateDBInstanceReadReplica, DeleteDBInstance, DescribeDBInstances, ModifyDBInstance, PromoteReadReplica, RebootDBInstance, RestoreDBInstanceFromDBSnapshot, RestoreDBInstanceFromS3, RestoreDBInstanceToPointInTime, StartDBInstance, and StopDBInstance.
AWS API: rds.v1.DBInstance
Reference: https://docs.aws.amazon.com/AmazonRDS/latest/APIReference//DBInstance
Coverage
24 of 90 fields included. Omitted fields:
DBSecurityGroups— not selected in manifestVpcSecurityGroups— not selected in manifestDBParameterGroups— not selected in manifestDBSubnetGroup— not selected in manifestUpgradeRolloutOrder— not selected in manifestPendingModifiedValues— not selected in manifestLatestRestorableTime— not selected in manifestReadReplicaSourceDBInstanceIdentifier— not selected in manifestReadReplicaDBInstanceIdentifiers— not selected in manifestReadReplicaDBClusterIdentifiers— not selected in manifestReplicaMode— not selected in manifestLicenseModel— not selected in manifestOptionGroupMemberships— not selected in manifestCharacterSetName— not selected in manifestNcharCharacterSetName— not selected in manifestSecondaryAvailabilityZone— not selected in manifestStatusInfos— not selected in manifestTdeCredentialArn— not selected in manifestDbInstancePort— not selected in manifestDBClusterIdentifier— not selected in manifestCACertificateIdentifier— not selected in manifestDomainMemberships— not selected in manifestCopyTagsToSnapshot— not selected in manifestMonitoringInterval— not selected in manifestEnhancedMonitoringResourceArn— not selected in manifestMonitoringRoleArn— not selected in manifestPromotionTier— not selected in manifestTimezone— not selected in manifestIAMDatabaseAuthenticationEnabled— not selected in manifestDatabaseInsightsMode— not selected in manifestPerformanceInsightsEnabled— not selected in manifestPerformanceInsightsKMSKeyId— not selected in manifestPerformanceInsightsRetentionPeriod— not selected in manifestEnabledCloudwatchLogsExports— not selected in manifestProcessorFeatures— not selected in manifestDeletionProtection— not selected in manifestAssociatedRoles— not selected in manifestListenerEndpoint— not selected in manifestMaxAllocatedStorage— not selected in manifestTagList— not selected in manifestAutomationMode— not selected in manifestResumeFullAutomationModeTime— not selected in manifestCustomerOwnedIpEnabled— not selected in manifestNetworkType— not selected in manifestActivityStreamStatus— not selected in manifestActivityStreamKmsKeyId— not selected in manifestActivityStreamKinesisStreamName— not selected in manifestActivityStreamMode— not selected in manifestActivityStreamEngineNativeAuditFieldsIncluded— not selected in manifestAwsBackupRecoveryPointArn— not selected in manifestDBInstanceAutomatedBackupsReplications— not selected in manifestBackupTarget— not selected in manifestAutomaticRestartTime— not selected in manifestCustomIamInstanceProfile— not selected in manifestActivityStreamPolicyStatus— not selected in manifestCertificateDetails— not selected in manifestDBSystemId— not selected in manifestMasterUserSecret— not selected in manifestReadReplicaSourceDBClusterIdentifier— not selected in manifestPercentProgress— not selected in manifestMultiTenant— not selected in manifestDedicatedLogVolume— not selected in manifestIsStorageConfigUpgradeAvailable— not selected in manifestEngineLifecycleSupport— not selected in manifestAdditionalStorageVolumes— not selected in manifestStorageVolumeStatus— not selected in manifest
Fields
db_instance_identifier: Option<String>The user-supplied database identifier. This identifier is the unique key that identifies a DB instance.
db_instance_class: Option<String>The name of the compute and memory capacity class of the DB instance.
engine: Option<String>The database engine used for this DB instance.
db_instance_status: Option<String>The current state of this database. For information about DB instance statuses, see Viewing DB instance status in the Amazon RDS User Guide.
master_username: Option<String>The master username for the DB instance.
db_name: Option<String>The initial database name that you provided (if required) when you created the DB instance. This name is returned for the life of your DB instance. For an RDS for Oracle CDB instance, the name identifies the PDB rather than the CDB.
endpoint: Option<Endpoint>The connection endpoint for the DB instance. The endpoint might not be shown for instances with the status of creating.
allocated_storage: Option<i32>The amount of storage in gibibytes (GiB) allocated for the DB instance.
instance_create_time: Option<String>The date and time when the DB instance was created.
preferred_backup_window: Option<String>The daily time range during which automated backups are created if automated backups are enabled, as determined by the BackupRetentionPeriod.
backup_retention_period: Option<i32>The number of days for which automatic DB snapshots are retained.
availability_zone: Option<String>The name of the Availability Zone where the DB instance is located.
preferred_maintenance_window: Option<String>The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
multi_az: Option<bool>Indicates whether the DB instance is a Multi-AZ deployment. This setting doesn’t apply to RDS Custom DB instances.
engine_version: Option<String>The version of the database engine.
auto_minor_version_upgrade: Option<bool>Indicates whether minor version patches are applied automatically. For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.
publicly_accessible: Option<bool>Indicates whether the DB instance is publicly accessible. When the DB instance is publicly accessible and you connect from outside of the DB instance’s virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB instance, the endpoint resolves to the private IP address. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn’t permitted if the security group assigned to the DB cluster doesn’t permit it. When the DB instance isn’t publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address. For more information, see CreateDBInstance.
storage_type: Option<String>The storage type associated with the DB instance.
storage_encrypted: Option<bool>Indicates whether the DB instance is encrypted.
kms_key_id: Option<String>If StorageEncrypted is enabled, the Amazon Web Services KMS key identifier for the encrypted DB instance. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
dbi_resource_id: Option<String>The Amazon Web Services Region-unique, immutable identifier for the DB instance. This identifier is found in Amazon Web Services CloudTrail log entries whenever the Amazon Web Services KMS key for the DB instance is accessed.
db_instance_arn: Option<String>The Amazon Resource Name (ARN) for the DB instance.
iops: Option<i32>The Provisioned IOPS (I/O operations per second) value for the DB instance.
storage_throughput: Option<i32>The storage throughput for the DB instance. This setting applies only to the gp3 storage type.