pub struct DeleteDBInstanceRequest {
pub db_instance_identifier: String,
pub skip_final_snapshot: Option<bool>,
pub final_db_snapshot_identifier: Option<String>,
pub delete_automated_backups: Option<bool>,
}Expand description
AWS API: rds.v1.DeleteDBInstanceMessage
Reference: https://docs.aws.amazon.com/AmazonRDS/latest/APIReference//DeleteDBInstanceMessage
Fields
db_instance_identifier: StringThe DB instance identifier for the DB instance to be deleted. This parameter isn’t case- sensitive. Constraints: Must match the name of an existing DB instance.
skip_final_snapshot: Option<bool>Specifies whether to skip the creation of a final DB snapshot before deleting the instance. If you enable this parameter, RDS doesn’t create a DB snapshot. If you don’t enable this parameter, RDS creates a DB snapshot before the DB instance is deleted. By default, skip isn’t enabled, and the DB snapshot is created. If you don’t enable this parameter, you must specify the FinalDBSnapshotIdentifier parameter. When a DB instance is in a failure state and has a status of failed, incompatible-restore, or incompatible- network, RDS can delete the instance only if you enable this parameter. If you delete a read replica or an RDS Custom instance, you must enable this setting. This setting is required for RDS Custom.
final_db_snapshot_identifier: Option<String>The DBSnapshotIdentifier of the new DBSnapshot created when the SkipFinalSnapshot parameter is disabled. If you enable this parameter and also enable SkipFinalShapshot, the command results in an error. This setting doesn’t apply to RDS Custom. Constraints: Must be 1 to 255 letters or numbers. First character must be a letter. Can’t end with a hyphen or contain two consecutive hyphens. Can’t be specified when deleting a read replica.
delete_automated_backups: Option<bool>Specifies whether to remove automated backups immediately after the DB instance is deleted. This parameter isn’t case-sensitive. The default is to remove automated backups immediately after the DB instance is deleted.