pub struct DescribeClustersRequest {
pub cluster_identifier: Option<String>,
pub max_records: Option<i32>,
pub marker: Option<String>,
}Expand description
AWS API: redshift.v1.DescribeClustersMessage
Reference: https://docs.aws.amazon.com/redshift/latest/APIReference//DescribeClustersMessage
Coverage
3 of 5 fields included. Omitted fields:
TagKeys— not selected in manifestTagValues— not selected in manifest
Fields
cluster_identifier: Option<String>The unique identifier of a cluster whose properties you are requesting. This parameter is case sensitive. The default is that all clusters defined for an account are returned.
max_records: Option<i32>The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value. Default: 100 Constraints: minimum 20, maximum 100.
marker: Option<String>An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusters request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. Constraints: You can specify either the ClusterIdentifier parameter or the Marker parameter, but not both.