pub struct RotateSecretRequest {
pub secret_id: String,
pub rotation_lambda_arn: Option<String>,
pub rotation_rules: Option<RotationRulesType>,
pub rotate_immediately: Option<bool>,
}Expand description
AWS API: secretsmanager.v1.RotateSecretRequest
Coverage
4 of 7 fields included. Omitted fields:
ClientRequestToken— not selected in manifestExternalSecretRotationMetadata— not selected in manifestExternalSecretRotationRoleArn— not selected in manifest
Fields
secret_id: StringThe ARN or name of the secret to rotate. For an ARN, we recommend that you specify a complete ARN rather than a partial ARN. See Finding a secret from a partial ARN.
rotation_lambda_arn: Option<String>For secrets that use a Lambda rotation function to rotate, the ARN of the Lambda rotation function. For secrets that use managed rotation, omit this field. For more information, see Managed rotation in the Secrets Manager User Guide.
rotation_rules: Option<RotationRulesType>A structure that defines the rotation configuration for this secret. When changing an existing rotation schedule and setting RotateImmediately to false: If using AutomaticallyAfterDays or a ScheduleExpression with rate(), the previously scheduled rotation might still occur. To prevent unintended rotations, use a ScheduleExpression with cron() for granular control over rotation windows.
rotate_immediately: Option<bool>Specifies whether to rotate the secret immediately or wait until the next scheduled rotation window. The rotation schedule is defined in RotateSecretRequest$RotationRules. The default for RotateImmediately is true. If you don’t specify this value, Secrets Manager rotates the secret immediately. If you set RotateImmediately to false, Secrets Manager tests the rotation configuration by running the testSecret step of the Lambda rotation function. This test creates an AWSPENDING version of the secret and then removes it. When changing an existing rotation schedule and setting RotateImmediately to false: If using AutomaticallyAfterDays or a ScheduleExpression with rate(), the previously scheduled rotation might still occur. To prevent unintended rotations, use a ScheduleExpression with cron() for granular control over rotation windows. Rotation is an asynchronous process. For more information, see How rotation works.